WebFormsCore

package module
v0.0.0-...-008e2f9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2026 License: MIT Imports: 3 Imported by: 0

README

GO

webforms.go - The Back-End Part of WebForms Core Technology, Owned by Elanat (https://elanat.net)

This repository is a Go module.

Documentation

Index

Constants

const (
	GS = string(rune(29))
	US = string(rune(31))
)
const (
	FetchRS = string(rune(30))
	FetchUS = string(rune(31))
)

Variables

var Fetch = fetch{

	DateYear:         "@dy",
	DateMonth:        "@dm",
	DateDay:          "@dd",
	DateDate:         "@dD",
	DateHours:        "@dh",
	DateMinutes:      "@di",
	DateSeconds:      "@ds",
	DateMilliseconds: "@dl",

	Space:  "@sp",
	AtSign: "@sa",

	TabIsActive: "@da",

	Href:         "@wf",
	PathName:     "@wP",
	Hash:         "@wh",
	Host:         "@wH",
	HostName:     "@wn",
	Port:         "@wT",
	Origin:       "@wo",
	GetSelection: "@ws",
	ScrollX:      "@wx",
	ScrollY:      "@wy",

	ClipboardText: "@nC",
	GeoLatitude:   "@nW",
	GeoLongitude:  "@nO",
	Language:      "@nL",
	IsOnLine:      "@no",
	UserAgent:     "@na",

	ScreenWidth:            "@sw",
	ScreenHeight:           "@sh",
	ScreenOrientationType:  "@so",
	ScreenOrientationAngle: "@sr",

	TimeOrigin:     "@pt",
	PerformanceNow: "@pn",

	Event:          "@EV",
	EventSerialize: "@Es",
	EventKey:       "@ek",
	EventWhich:     "@ew",
	EventClientX:   "@ex",
	EventClientY:   "@ey",
	EventPageX:     "@eX",
	EventPageY:     "@eY",
	EventOffsetX:   "@Ex",
	EventOffsetY:   "@Ey",
	EventDeltaY:    "@ed",
}
var HtmlEvent = htmlEvent{
	OnAbort:          "onabort",
	OnAfterPrint:     "onafterprint",
	OnBeforePrint:    "onbeforeprint",
	OnBeforeUnload:   "onbeforeunload",
	OnBlur:           "onblur",
	OnCanPlay:        "oncanplay",
	OnCanPlayThrough: "oncanplaythrough",
	OnChange:         "onchange",
	OnClick:          "onclick",
	OnCopy:           "oncopy",
	OnCut:            "oncut",
	OnDoubleClick:    "ondblclick",
	OnDrag:           "ondrag",
	OnDragEnd:        "ondragend",
	OnDragEnter:      "ondragenter",
	OnDragLeave:      "ondragleave",
	OnDragOver:       "ondragover",
	OnDragStart:      "ondragstart",
	OnDrop:           "ondrop",
	OnDurationChange: "ondurationchange",
	OnEnded:          "onended",
	OnError:          "onerror",
	OnFocus:          "onfocus",
	OnFocusin:        "onfocusin",
	OnFocusOut:       "onfocusout",
	OnHashChange:     "onhashchange",
	OnInput:          "oninput",
	OnInvalid:        "oninvalid",
	OnKeyDown:        "onkeydown",
	OnKeyPress:       "onkeypress",
	OnKeyUp:          "onkeyup",
	OnLoad:           "onload",
	OnLoadedData:     "onloadeddata",
	OnLoadedMetaData: "onloadedmetadata",
	OnLoadStart:      "onloadstart",
	OnMouseDown:      "onmousedown",
	OnMouseEnter:     "onmouseenter",
	OnMouseLeave:     "onmouseleave",
	OnMouseMove:      "onmousemove",
	OnMouseOver:      "onmouseover",
	OnMouseOut:       "onmouseout",
	OnMouseUp:        "onmouseup",
	OnOffline:        "onoffline",
	OnOnline:         "ononline",
	OnPageHide:       "onpagehide",
	OnPageShow:       "onpageshow",
	OnPaste:          "onpaste",
	OnPause:          "onpause",
	OnPlay:           "onplay",
	OnPlaying:        "onplaying",
	OnProgress:       "onprogress",
	OnRateChange:     "onratechange",
	OnResize:         "onresize",
	OnReset:          "onreset",
	OnScroll:         "onscroll",
	OnSearch:         "onsearch",
	OnSeeked:         "onseeked",
	OnSeeking:        "onseeking",
	OnSelect:         "onselect",
	OnStalled:        "onstalled",
	OnSubmit:         "onsubmit",
	OnSuspend:        "onsuspend",
	OnTimeUpdate:     "ontimeupdate",
	OnToggle:         "ontoggle",
	OnTouchCancel:    "ontouchcancel",
	OnTouchend:       "ontouchend",
	OnTouchMove:      "ontouchmove",
	OnTouchStart:     "ontouchstart",
	OnUnload:         "onunload",
	OnVolumeChange:   "onvolumechange",
	OnWaiting:        "onwaiting",
	OnWheel:          "onwheel",
}
var HtmlEventListener = htmlEventListener{
	Paste:        "paste",
	Pause:        "pause",
	Play:         "play",
	Playing:      "playing",
	Progress:     "progress",
	RateChange:   "ratechange",
	Resize:       "resize",
	Reset:        "reset",
	Scroll:       "scroll",
	Search:       "search",
	Seeked:       "seeked",
	Seeking:      "seeking",
	Select:       "select",
	Stalled:      "stalled",
	Submit:       "submit",
	Suspend:      "suspend",
	TimeUpdate:   "timeupdate",
	Toggle:       "toggle",
	TouchCancel:  "touchcancel",
	Touchend:     "touchend",
	TouchMove:    "touchmove",
	TouchStart:   "touchstart",
	Unload:       "unload",
	VolumeChange: "volumechange",
	Waiting:      "waiting",
	Wheel:        "wheel",

	AnimationEnd:       "animationend",
	AnimationIteration: "animationiteration",
	AnimationStart:     "animationstart",
	ContextMenu:        "contextmenu",
	FullScreenChange:   "fullscreenchange",
	FullScreenError:    "fullscreenerror",
	PopState:           "popstate",
	TransitionEnd:      "transitionend",
	Storage:            "storage",

	ScrollBottom:   "scrollbottom",
	ElementReached: "elementreached",
}
var InputPlace = inputPlace{
	Document:          ",",
	Window:            "`",
	Root:              "~",
	HTML:              ".",
	Head:              "^",
	ScreenOrientation: "%",
	All:               "*",
	Parent:            "/",
	Current:           "$",
	Target:            "!",
	Upper:             "-",
}
var WasmLanguage = wasmLanguage{

	C:      "c",
	CPP:    "c",
	Rust:   "rust",
	CSharp: "csharp",

	CSharpMediator: "csharp-m",
	GO:             "go",
	JAVA:           "java",
	AssemblyScript: "as",
}

Functions

func AppendFetchReplace

func AppendFetchReplace(text string, searchValue string, value string) string

func Child

func Child(text string, value string) string

func Criteria

func Criteria(text string, value string) string

func LineBreak

func LineBreak(text string, encodeLine bool) string

func Parent

func Parent(text string) string

func ToJSObject

func ToJSObject(text string) string

Get JS Object Momentary

func ToJSReturnObject

func ToJSReturnObject(text string) string

Get JS Object Returned Value Once

func ToJSString

func ToJSString(text string) string

Converts Numbers to Strings

Types

type OutputPlace

type OutputPlace struct {
	// contains filtered or unexported fields
}

func (OutputPlace) AllAttributes

func (OutputPlace) AllAttributes(name string) string

func (OutputPlace) AllAttributesValue

func (OutputPlace) AllAttributesValue(name string, value string, operator ...rune) string

func (OutputPlace) AllChild

func (OutputPlace) AllChild() string

func (OutputPlace) AllClasses

func (OutputPlace) AllClasses(class string) string

func (OutputPlace) AllNames

func (OutputPlace) AllNames(name string) string

func (OutputPlace) AllTags

func (OutputPlace) AllTags(tag string) string

func (OutputPlace) Attribute

func (OutputPlace) Attribute(name string) string

func (OutputPlace) AttributeIndex

func (OutputPlace) AttributeIndex(name string, index int) string

func (OutputPlace) AttributeValue

func (OutputPlace) AttributeValue(name string, value string, operator ...rune) string

Operator: '^', '$', '*', '~'

func (OutputPlace) AttributeValueIndex

func (OutputPlace) AttributeValueIndex(name string, value string, index int, operator ...rune) string

func (OutputPlace) Child

func (OutputPlace) Child() string

func (OutputPlace) ChildIndex

func (OutputPlace) ChildIndex(index int) string

func (OutputPlace) Class

func (OutputPlace) Class(class string) string

func (OutputPlace) ClassIndex

func (OutputPlace) ClassIndex(class string, index int) string

func (OutputPlace) Id

func (OutputPlace) Id(id string) string

func (OutputPlace) Name

func (OutputPlace) Name(name string) string

func (OutputPlace) NameIndex

func (OutputPlace) NameIndex(name string, index int) string

func (OutputPlace) Query

func (OutputPlace) Query(query string) string

func (OutputPlace) QueryAll

func (OutputPlace) QueryAll(query string) string

func (OutputPlace) Tag

func (OutputPlace) Tag(tag string) string

func (OutputPlace) TagIndex

func (OutputPlace) TagIndex(tag string, index int) string

type Security

type Security struct {
}

func (*Security) SafeValue

func (s *Security) SafeValue(value string) string

type WebForms

type WebForms struct {
	// contains filtered or unexported fields
}

func New

func New() *WebForms

func (*WebForms) AddAttribute

func (w *WebForms) AddAttribute(inputPlace string, attribute string, args ...any)

func (*WebForms) AddCacheValue

func (w *WebForms) AddCacheValue(cacheKey string, value string)

func (*WebForms) AddCheckBoxTag

func (w *WebForms) AddCheckBoxTag(inputPlace string, text string, value string, checked ...bool)

func (*WebForms) AddClass

func (w *WebForms) AddClass(inputPlace string, class string)

func (*WebForms) AddHidden

func (w *WebForms) AddHidden(inputPlace string, name string, value string, id ...string)

func (*WebForms) AddINI

func (w *WebForms) AddINI(key string, path string, value string, isINILike bool)

func (*WebForms) AddId

func (w *WebForms) AddId(inputPlace string, id string)

Add Creates the Data if it does not exist; otherwise, Appends the New Value to the Existing Value.

func (*WebForms) AddJSON

func (w *WebForms) AddJSON(key string, path string, value string)

func (*WebForms) AddLabel

func (w *WebForms) AddLabel(inputPlace string, label string)

func (*WebForms) AddLine

func (w *WebForms) AddLine(name string, value string)

For Extension

func (*WebForms) AddName

func (w *WebForms) AddName(inputPlace string, name string)

func (*WebForms) AddOptionTag

func (w *WebForms) AddOptionTag(inputPlace string, text string, value string, selected ...bool)

func (*WebForms) AddSaveValue

func (w *WebForms) AddSaveValue(cacheKey string, value string)

func (*WebForms) AddState

func (w *WebForms) AddState(path ...string)

State

func (*WebForms) AddStyle

func (w *WebForms) AddStyle(inputPlace string, args ...string)

func (*WebForms) AddTag

func (w *WebForms) AddTag(inputPlace string, tagName string, id ...string)

func (*WebForms) AddTagAfter

func (w *WebForms) AddTagAfter(inputPlace string, tagName string, id ...string)

func (*WebForms) AddTagBefore

func (w *WebForms) AddTagBefore(inputPlace string, tagName string, id ...string)

func (*WebForms) AddTagToUp

func (w *WebForms) AddTagToUp(inputPlace string, tagName string, id ...string)

func (*WebForms) AddText

func (w *WebForms) AddText(inputPlace string, text string)

func (*WebForms) AddTextLine

func (w *WebForms) AddTextLine(key string, line string, text string)

func (*WebForms) AddTextLineInt

func (w *WebForms) AddTextLineInt(key string, line int, text string)

func (*WebForms) AddTextToUp

func (w *WebForms) AddTextToUp(inputPlace string, text string)

func (*WebForms) AddTitle

func (w *WebForms) AddTitle(inputPlace string, title string)

func (*WebForms) AddValue

func (w *WebForms) AddValue(inputPlace string, value string)

func (*WebForms) AddVariable

func (w *WebForms) AddVariable(key string, value string)

func (*WebForms) AddWebSocket

func (w *WebForms) AddWebSocket(path string)

func (*WebForms) AddXML

func (w *WebForms) AddXML(key string, path string, name string, value string)

Name: For Support Attribute, Set Double At Sign (@@) Before Name.

func (*WebForms) Alert

func (w *WebForms) Alert(text string, args ...string)

Message Type: warning, problem, help, success, none

func (*WebForms) AppendCacheValue

func (w *WebForms) AppendCacheValue(cacheKey string, value string)

func (*WebForms) AppendForm

func (w *WebForms) AppendForm(form *WebForms)

func (*WebForms) AppendSaveValue

func (w *WebForms) AppendSaveValue(cacheKey string, value string)

func (*WebForms) AssertEqual

func (w *WebForms) AssertEqual(inputPlace string, tag string)

Unit Testing InputPlace Is Actual, Expected Is Tag/OutputPlace

func (*WebForms) AssertEqualByOutputPlace

func (w *WebForms) AssertEqualByOutputPlace(inputPlace string, outputPlace string)

func (*WebForms) AssignConfirmEvent

func (w *WebForms) AssignConfirmEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) AssignDelay

func (w *WebForms) AssignDelay(miliSecond int, index ...int)

Pre Runner

func (*WebForms) AssignDelayChange

func (w *WebForms) AssignDelayChange(miliSecond int, index ...int)

func (*WebForms) AssignInterval

func (w *WebForms) AssignInterval(miliSecond int, id string, index ...int)

func (*WebForms) AssignIntervalChange

func (w *WebForms) AssignIntervalChange(miliSecond int, id string, index ...int)

func (*WebForms) AssignRepeat

func (w *WebForms) AssignRepeat(count int, index ...int)

func (*WebForms) AssignRepeatChange

func (w *WebForms) AssignRepeatChange(count int, index ...int)

func (*WebForms) AssignReplace

func (w *WebForms) AssignReplace(searchValue string, value string, index int)

func (*WebForms) Async

func (w *WebForms) Async() *WebForms

Async It Supports Brackets and Then

func (*WebForms) BindINIToTemplate

func (w *WebForms) BindINIToTemplate(inputPlace string, iniText string, path string, pattern string, alsoStartTag bool)

func (*WebForms) BindJSONToTemplate

func (w *WebForms) BindJSONToTemplate(inputPlace string, jsonText string, path string, pattern string, alsoStartTag bool)

Template Engine Pattern Example: {{value}}, ((value)), *value*, $value;

func (*WebForms) BindXMLToTemplate

func (w *WebForms) BindXMLToTemplate(inputPlace string, xmlText string, path string, pattern string, alsoStartTag bool)

Because XML Elements Are Lowercased, Placeholders Must Use Lowercase Names.

func (*WebForms) Break

func (w *WebForms) Break()

func (*WebForms) CacheAttribute

func (w *WebForms) CacheAttribute(inputPlace string, attribute string, key ...string)

func (*WebForms) CacheClass

func (w *WebForms) CacheClass(inputPlace string, key ...string)

func (*WebForms) CacheHeight

func (w *WebForms) CacheHeight(inputPlace string, key ...string)

func (*WebForms) CacheId

func (w *WebForms) CacheId(inputPlace string, key ...string)

Cache

func (*WebForms) CacheIndex

func (w *WebForms) CacheIndex(inputPlace string, key ...string)

func (*WebForms) CacheLabel

func (w *WebForms) CacheLabel(inputPlace string, key ...string)

func (*WebForms) CacheName

func (w *WebForms) CacheName(inputPlace string, key ...string)

func (*WebForms) CacheNodeLength

func (w *WebForms) CacheNodeLength(inputPlace string, key ...string)

func (*WebForms) CacheOuterText

func (w *WebForms) CacheOuterText(inputPlace string, key ...string)

func (*WebForms) CacheReadOnly

func (w *WebForms) CacheReadOnly(inputPlace string, key ...string)

func (*WebForms) CacheSelectedIndex

func (w *WebForms) CacheSelectedIndex(inputPlace string, key ...string)

func (*WebForms) CacheStyle

func (w *WebForms) CacheStyle(inputPlace string, key ...string)

func (*WebForms) CacheText

func (w *WebForms) CacheText(inputPlace string, key ...string)

func (*WebForms) CacheTextAlign

func (w *WebForms) CacheTextAlign(inputPlace string, key ...string)

func (*WebForms) CacheTextLength

func (w *WebForms) CacheTextLength(inputPlace string, key ...string)

func (*WebForms) CacheTitle

func (w *WebForms) CacheTitle(inputPlace string, key ...string)

func (*WebForms) CacheUrl

func (w *WebForms) CacheUrl(url string, fetchScript ...any)

func (*WebForms) CacheValue

func (w *WebForms) CacheValue(inputPlace string, key ...string)

func (*WebForms) CacheValueLength

func (w *WebForms) CacheValueLength(inputPlace string, key ...string)

func (*WebForms) CacheVisible

func (w *WebForms) CacheVisible(inputPlace string, key ...string)

func (*WebForms) CacheWidth

func (w *WebForms) CacheWidth(inputPlace string, key ...string)

func (*WebForms) CallCommentBack

func (w *WebForms) CallCommentBack(index ...any)

func (*WebForms) CallDeleteBack

func (w *WebForms) CallDeleteBack(path string, args ...any)

func (*WebForms) CallFront

func (w *WebForms) CallFront(modulePath string, args ...any)

func (*WebForms) CallGetBack

func (w *WebForms) CallGetBack(path string, args ...any)

func (*WebForms) CallHeadBack

func (w *WebForms) CallHeadBack(path string, useCurrentEvent ...bool)

func (*WebForms) CallMethod

func (w *WebForms) CallMethod(methodName string, args ...any)

func (*WebForms) CallModuleMethod

func (w *WebForms) CallModuleMethod(methodName string, args ...any)

func (*WebForms) CallOptionsBack

func (w *WebForms) CallOptionsBack(path string, args ...any)

func (*WebForms) CallPatchBack

func (w *WebForms) CallPatchBack(path string, args ...any)

func (*WebForms) CallPostBack

func (w *WebForms) CallPostBack(formInputPlace string, outputPlace ...string)

func (*WebForms) CallPutBack

func (w *WebForms) CallPutBack(path string, args ...any)

func (*WebForms) CallSSEBack

func (w *WebForms) CallSSEBack(path string, args ...any)

func (*WebForms) CallScript

func (w *WebForms) CallScript(scriptText string)

func (*WebForms) CallSendBack

func (w *WebForms) CallSendBack(path string, method string, isMultiPart bool, contentType string, data string, args ...any)

func (*WebForms) CallWasmBack

func (w *WebForms) CallWasmBack(wasmLanguage string, wasmUrl string, methodName string, args ...any)

func (*WebForms) CallWebSocketBack

func (w *WebForms) CallWebSocketBack(path string, useCurrentEvent ...bool)

func (*WebForms) ChangeOption

func (w *WebForms) ChangeOption(name string, value string)

Option

func (*WebForms) ChangeUrl

func (w *WebForms) ChangeUrl(url string)

Browser

func (*WebForms) ChecksumCalculation

func (w *WebForms) ChecksumCalculation(text string) string

func (*WebForms) Clean

func (w *WebForms) Clean()

func (*WebForms) ClipboardWriteText

func (w *WebForms) ClipboardWriteText(text string)

func (*WebForms) ConfirmIsFalseAccept

func (w *WebForms) ConfirmIsFalseAccept(text string, typ string, title string, okText string, cancelText string, interval int) *WebForms

func (*WebForms) ConfirmIsTrueAccept

func (w *WebForms) ConfirmIsTrueAccept(text string, typ string, title string, okText string, cancelText string, interval int) *WebForms

Condition And Loop Condition And Loop Supports Brackets and Then Type: warning, problem, help, success, none Interval: Value 0 is Await (if is not True, all Next Action Controls Waiting for it), Value -1 is Sync Check Once (is Support Bracket or Next Action Control), Value > 0 is Async and is Wait Based on Time Repetition Until it Becomes True (Is Support Bracket or Next Action Control, but is not Support Else). Nested Conditions and Nested Loops are Possible.

func (*WebForms) ConsoleMessage

func (w *WebForms) ConsoleMessage(text string, typ ...string)

Type: log, info, warn, error, debug, trace, group, groupend, table

func (*WebForms) ConsoleMessageAssert

func (w *WebForms) ConsoleMessageAssert(text string, condition string)

func (*WebForms) CreateCustomDOMEvent

func (w *WebForms) CreateCustomDOMEvent(inputPlace string, eventName string, watch string, key string, compare string, value string, rangeValue string, immediate bool, delay any)

Custom Event This Method Is Compatible With EventListener And May Not Be Compatible With Events Written As Attributes In Some Browsers. Watch: attribute, style, text, children, value Compare: greater, less, equal, notequal, includes, startswith, endswith, matches, changed, inrange, lengthgreater, lengthless, lengthequal Range: Only Use For Compare With inrange Value. Split By Comma "," Key: Only Use For Watch With attribute And style Value

func (*WebForms) CreateDebugger

func (w *WebForms) CreateDebugger(pause ...bool)

Debug

func (*WebForms) CreateFormatStorage

func (w *WebForms) CreateFormatStorage(key string, data string)

Format Storage

func (*WebForms) Decrease

func (w *WebForms) Decrease(inputPlace string, value float32)

func (*WebForms) DecreaseFontSize

func (w *WebForms) DecreaseFontSize(inputPlace string, value any)

func (*WebForms) DecreaseHeight

func (w *WebForms) DecreaseHeight(inputPlace string, value any)

func (*WebForms) DecreaseMaxLength

func (w *WebForms) DecreaseMaxLength(inputPlace string, value any)

func (*WebForms) DecreaseMinLength

func (w *WebForms) DecreaseMinLength(inputPlace string, value any)

Decrease

func (*WebForms) DecreaseValue

func (w *WebForms) DecreaseValue(inputPlace string, value any)

func (*WebForms) DecreaseVariable

func (w *WebForms) DecreaseVariable(key string, value int)

func (*WebForms) DecreaseWidth

func (w *WebForms) DecreaseWidth(inputPlace string, value any)

func (*WebForms) Delay

func (w *WebForms) Delay(milliseconds string)

func (*WebForms) DelayInt

func (w *WebForms) DelayInt(milliseconds int)

func (*WebForms) Delete

func (w *WebForms) Delete(inputPlace string)

func (*WebForms) DeleteAllCheckBoxTag

func (w *WebForms) DeleteAllCheckBoxTag(inputPlace string)

func (*WebForms) DeleteAllOptionTag

func (w *WebForms) DeleteAllOptionTag(inputPlace string)

func (*WebForms) DeleteAllState

func (w *WebForms) DeleteAllState()

func (*WebForms) DeleteAttribute

func (w *WebForms) DeleteAttribute(inputPlace string, attribute string)

func (*WebForms) DeleteCheckBoxTag

func (w *WebForms) DeleteCheckBoxTag(inputPlace string, value string)

func (*WebForms) DeleteClass

func (w *WebForms) DeleteClass(inputPlace string, className string)

func (*WebForms) DeleteFormatStorage

func (w *WebForms) DeleteFormatStorage(key string)

func (*WebForms) DeleteINI

func (w *WebForms) DeleteINI(key string, path string, isINILike ...bool)

func (*WebForms) DeleteId

func (w *WebForms) DeleteId(inputPlace string)

Delete

func (*WebForms) DeleteInterval

func (w *WebForms) DeleteInterval(id string)

func (*WebForms) DeleteJSON

func (w *WebForms) DeleteJSON(key string, path string)

func (*WebForms) DeleteLabel

func (w *WebForms) DeleteLabel(inputPlace string)

func (*WebForms) DeleteModuleMethod

func (w *WebForms) DeleteModuleMethod(methodName string)

func (*WebForms) DeleteName

func (w *WebForms) DeleteName(inputPlace string)

func (*WebForms) DeleteOptionTag

func (w *WebForms) DeleteOptionTag(inputPlace string, value string)

func (*WebForms) DeleteParent

func (w *WebForms) DeleteParent(inputPlace string)

func (*WebForms) DeleteState

func (w *WebForms) DeleteState(path ...string)

func (*WebForms) DeleteStyle

func (w *WebForms) DeleteStyle(inputPlace string, styleName string)

func (*WebForms) DeleteText

func (w *WebForms) DeleteText(inputPlace string)

func (*WebForms) DeleteTextLine

func (w *WebForms) DeleteTextLine(key string, line string)

func (*WebForms) DeleteTextLineInt

func (w *WebForms) DeleteTextLineInt(key string, line int)

func (*WebForms) DeleteTitle

func (w *WebForms) DeleteTitle(inputPlace string)

func (*WebForms) DeleteValue

func (w *WebForms) DeleteValue(inputPlace string)

func (*WebForms) DeleteVariable

func (w *WebForms) DeleteVariable(key string)

func (*WebForms) DeleteWebSocket

func (w *WebForms) DeleteWebSocket(path string)

Disconnected WebSocket

func (*WebForms) DeleteXML

func (w *WebForms) DeleteXML(key string, path string)

func (*WebForms) DisconnectAllSSE

func (w *WebForms) DisconnectAllSSE()

func (*WebForms) DisconnectSSE

func (w *WebForms) DisconnectSSE(path string)

SSE

func (*WebForms) ElementExists

func (w *WebForms) ElementExists(inputPlace string, interval int) *WebForms

func (*WebForms) ElementNotExists

func (w *WebForms) ElementNotExists(inputPlace string, interval int) *WebForms

func (*WebForms) Else

func (w *WebForms) Else() *WebForms

func (*WebForms) EnableReachedElementEvent

func (w *WebForms) EnableReachedElementEvent(inputPlace string, once bool, enable ...bool)

func (*WebForms) EnableScrollBottomEvent

func (w *WebForms) EnableScrollBottomEvent(enable ...bool)

func (*WebForms) EnableWebSocket

func (w *WebForms) EnableWebSocket(enable ...bool)

Enable Calling The EnableWebSocket Or EnableWebSocketOnce Or AddWebSocket Methods Will Cause Any Subsequent Requests (Under WebForms Core Technology) To Operate Under The WebSocket Protocol.

func (*WebForms) EnableWebSocketOnce

func (w *WebForms) EnableWebSocketOnce()

func (*WebForms) EndBracket

func (w *WebForms) EndBracket()

func (*WebForms) EndTransientDOM

func (w *WebForms) EndTransientDOM()

func (*WebForms) Exist

func (w *WebForms) Exist(value string, interval int) *WebForms

func (*WebForms) ExportToHtmlComment

func (w *WebForms) ExportToHtmlComment(addLine bool) string

Export

func (*WebForms) ExportToLineBreak

func (w *WebForms) ExportToLineBreak(src string) string

Using it for SSE Response

func (*WebForms) ForEach

func (w *WebForms) ForEach(path string, in string, key string) *WebForms

In: Everything Becomes A JSON List. Key: Creates A Temporary Data In The Browser IndexedDB. Key + "i" Creates A Temporary Data To Maintain The Loop Counter In The Browser IndexedDB.

func (*WebForms) GetChecksum

func (w *WebForms) GetChecksum() string

func (*WebForms) GetFormsActionData

func (w *WebForms) GetFormsActionData() string

Get

func (*WebForms) GetFormsActionDataLineBreak

func (w *WebForms) GetFormsActionDataLineBreak() string

func (*WebForms) GetwebFormsData

func (w *WebForms) GetwebFormsData() string

func (*WebForms) GoTo

func (w *WebForms) GoTo(line string, repeat ...string)

func (*WebForms) GoToIndex

func (w *WebForms) GoToIndex(index string, repeat ...int)

func (*WebForms) GoToInt

func (w *WebForms) GoToInt(line int, repeat ...int)

func (*WebForms) HistoryGo

func (w *WebForms) HistoryGo(steps any)

func (*WebForms) Include

func (w *WebForms) Include(text string, value string, interval int) *WebForms

func (*WebForms) Increase

func (w *WebForms) Increase(inputPlace string, value float32)

Update

func (*WebForms) IncreaseFontSize

func (w *WebForms) IncreaseFontSize(inputPlace string, value any)

func (*WebForms) IncreaseHeight

func (w *WebForms) IncreaseHeight(inputPlace string, value any)

func (*WebForms) IncreaseMaxLength

func (w *WebForms) IncreaseMaxLength(inputPlace string, value any)

func (*WebForms) IncreaseMinLength

func (w *WebForms) IncreaseMinLength(inputPlace string, value any)

Increase

func (*WebForms) IncreaseValue

func (w *WebForms) IncreaseValue(inputPlace string, value any)

func (*WebForms) IncreaseVariable

func (w *WebForms) IncreaseVariable(key string, value string)

func (*WebForms) IncreaseVariableInt

func (w *WebForms) IncreaseVariableInt(key string, value int)

func (*WebForms) IncreaseWidth

func (w *WebForms) IncreaseWidth(inputPlace string, value any)

func (*WebForms) Inject

func (w *WebForms) Inject(value string) string

Inject Need Add @: to First of String

func (*WebForms) InsertAttribute

func (w *WebForms) InsertAttribute(inputPlace string, attribute string, args ...any)

func (*WebForms) InsertCacheValue

func (w *WebForms) InsertCacheValue(cacheKey string, value string)

func (*WebForms) InsertCheckBoxTag

func (w *WebForms) InsertCheckBoxTag(inputPlace string, text string, value string, checked ...bool)

func (*WebForms) InsertClass

func (w *WebForms) InsertClass(inputPlace string, class string)

func (*WebForms) InsertId

func (w *WebForms) InsertId(inputPlace string, id string)

Insert Creates the Data only if it does not exist; otherwise, does nothing.

func (*WebForms) InsertLabel

func (w *WebForms) InsertLabel(inputPlace string, label string)

func (*WebForms) InsertName

func (w *WebForms) InsertName(inputPlace string, name string)

func (*WebForms) InsertOptionTag

func (w *WebForms) InsertOptionTag(inputPlace string, text string, value string, selected ...bool)

func (*WebForms) InsertSaveValue

func (w *WebForms) InsertSaveValue(cacheKey string, value string)

func (*WebForms) InsertStyle

func (w *WebForms) InsertStyle(inputPlace string, args ...string)

func (*WebForms) InsertText

func (w *WebForms) InsertText(inputPlace string, text string)

func (*WebForms) InsertTitle

func (w *WebForms) InsertTitle(inputPlace string, title string)

func (*WebForms) InsertValue

func (w *WebForms) InsertValue(inputPlace string, value string)

func (*WebForms) IsEqualTo

func (w *WebForms) IsEqualTo(firstValue string, secondValue string, interval int) *WebForms

func (*WebForms) IsFalse

func (w *WebForms) IsFalse(value string, interval int) *WebForms

func (*WebForms) IsGreaterThan

func (w *WebForms) IsGreaterThan(firstValue string, secondValue string, interval int) *WebForms

func (*WebForms) IsLessThan

func (w *WebForms) IsLessThan(firstValue string, secondValue string, interval int) *WebForms

func (*WebForms) IsMatchMedia

func (w *WebForms) IsMatchMedia(value string, interval int) *WebForms

func (*WebForms) IsNotEqualTo

func (w *WebForms) IsNotEqualTo(firstValue string, secondValue string, interval int) *WebForms

func (*WebForms) IsNotMatchMedia

func (w *WebForms) IsNotMatchMedia(value string, interval int) *WebForms

func (*WebForms) IsRegexMatch

func (w *WebForms) IsRegexMatch(value string, pattern string, interval int) *WebForms

func (*WebForms) IsRegexNotMatch

func (w *WebForms) IsRegexNotMatch(value string, pattern string, interval int) *WebForms

func (*WebForms) IsTrue

func (w *WebForms) IsTrue(value string, interval int) *WebForms

func (*WebForms) LoadModule

func (w *WebForms) LoadModule(modulePath string, methods ...[]string)

Module

func (*WebForms) LoadState

func (w *WebForms) LoadState(path string)

func (*WebForms) LoadUrl

func (w *WebForms) LoadUrl(inputPlace string, url string)

Call

func (*WebForms) Message

func (w *WebForms) Message(text string, args ...any)

func (*WebForms) NotExist

func (w *WebForms) NotExist(value string, interval int) *WebForms

func (*WebForms) NotInclude

func (w *WebForms) NotInclude(text string, value string, interval int) *WebForms

func (*WebForms) Redirect

func (w *WebForms) Redirect(path string)

func (*WebForms) ReloadPage

func (w *WebForms) ReloadPage()

func (*WebForms) RemoveAllCache

func (w *WebForms) RemoveAllCache()

func (*WebForms) RemoveAllSave

func (w *WebForms) RemoveAllSave()

func (*WebForms) RemoveCache

func (w *WebForms) RemoveCache(cacheKey string)

func (*WebForms) RemoveCommentEvent

func (w *WebForms) RemoveCommentEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveCommentEventListener

func (w *WebForms) RemoveCommentEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveConfirmEvent

func (w *WebForms) RemoveConfirmEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveDeleteEvent

func (w *WebForms) RemoveDeleteEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveDeleteEventListener

func (w *WebForms) RemoveDeleteEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveFrontEvent

func (w *WebForms) RemoveFrontEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveFrontEventListener

func (w *WebForms) RemoveFrontEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveGetEvent

func (w *WebForms) RemoveGetEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveGetEventListener

func (w *WebForms) RemoveGetEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveHeadEvent

func (w *WebForms) RemoveHeadEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveHeadEventListener

func (w *WebForms) RemoveHeadEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveMasterPagesEvent

func (w *WebForms) RemoveMasterPagesEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveMasterPagesEventListener

func (w *WebForms) RemoveMasterPagesEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveMethodEvent

func (w *WebForms) RemoveMethodEvent(inputPlace string, htmlEvent string, methodName string)

func (*WebForms) RemoveMethodEventListener

func (w *WebForms) RemoveMethodEventListener(inputPlace string, htmlEventListener string, methodName string)

func (*WebForms) RemoveModuleMethodEvent

func (w *WebForms) RemoveModuleMethodEvent(inputPlace string, htmlEvent string, methodName string)

func (*WebForms) RemoveModuleMethodEventListener

func (w *WebForms) RemoveModuleMethodEventListener(inputPlace string, htmlEventListener string, methodName string)

func (*WebForms) RemoveOptionsEvent

func (w *WebForms) RemoveOptionsEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveOptionsEventListener

func (w *WebForms) RemoveOptionsEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemovePatchEvent

func (w *WebForms) RemovePatchEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemovePatchEventListener

func (w *WebForms) RemovePatchEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemovePostEvent

func (w *WebForms) RemovePostEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemovePostEventListener

func (w *WebForms) RemovePostEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemovePreventDefaultEvent

func (w *WebForms) RemovePreventDefaultEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemovePreventDefaultEventListener

func (w *WebForms) RemovePreventDefaultEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemovePutEvent

func (w *WebForms) RemovePutEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemovePutEventListener

func (w *WebForms) RemovePutEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveSSEEvent

func (w *WebForms) RemoveSSEEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveSSEEventListener

func (w *WebForms) RemoveSSEEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveSave

func (w *WebForms) RemoveSave(cacheKey string)

func (*WebForms) RemoveSendEvent

func (w *WebForms) RemoveSendEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveSendEventListener

func (w *WebForms) RemoveSendEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveStopPropagationEvent

func (w *WebForms) RemoveStopPropagationEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveStopPropagationEventListener

func (w *WebForms) RemoveStopPropagationEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveWasmEvent

func (w *WebForms) RemoveWasmEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveWasmEventListener

func (w *WebForms) RemoveWasmEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) RemoveWebSocketEvent

func (w *WebForms) RemoveWebSocketEvent(inputPlace string, htmlEvent string)

func (*WebForms) RemoveWebSocketEventListener

func (w *WebForms) RemoveWebSocketEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) Repeat

func (w *WebForms) Repeat(newForm *WebForms, repeat int) *WebForms

func (*WebForms) RepeatConfigure

func (w *WebForms) RepeatConfigure(configure func(*WebForms), repeat int) *WebForms

func (*WebForms) RepeatConfigureWithIndex

func (w *WebForms) RepeatConfigureWithIndex(configure func(*WebForms), repeat int, index string) *WebForms

func (*WebForms) RepeatWithIndex

func (w *WebForms) RepeatWithIndex(newForm *WebForms, repeat int, index string) *WebForms

func (*WebForms) Replace

func (w *WebForms) Replace(inputPlace string, value string, newValue string, args ...bool)

If You Don't Use Deep Mode, any Tags Inside the Current Tag Will Simply Be Treated as Strings. Deep Mode Does not Remove Inner Elements.

func (*WebForms) ReplaceActionControl

func (w *WebForms) ReplaceActionControl(searchValue string, value string, addingToUp bool)

Action Control

func (*WebForms) ReplaceCacheValue

func (w *WebForms) ReplaceCacheValue(cacheKey string, searchValue string, value string)

func (*WebForms) ReplaceSaveValue

func (w *WebForms) ReplaceSaveValue(cacheKey string, searchValue string, value string)

func (*WebForms) ReplaceStartTag

func (w *WebForms) ReplaceStartTag(inputPlace string, value string, newValue string)

HTML Converts Attribute Names to Lowercase, so they Need to Be Written in Lowercase.

func (*WebForms) ResetOption

func (w *WebForms) ResetOption()

func (*WebForms) ResetOptionName

func (w *WebForms) ResetOptionName(name string)

func (*WebForms) Response

func (w *WebForms) Response() string

func (*WebForms) RunActionControls

func (w *WebForms) RunActionControls(actionControls string, withoutWebFormsSection ...any)

func (*WebForms) SaveAttribute

func (w *WebForms) SaveAttribute(inputPlace string, attribute string, key ...string)

func (*WebForms) SaveClass

func (w *WebForms) SaveClass(inputPlace string, key ...string)

func (*WebForms) SaveHeight

func (w *WebForms) SaveHeight(inputPlace string, key ...string)

func (*WebForms) SaveId

func (w *WebForms) SaveId(inputPlace string, key ...string)

Save (Session Cache)

func (*WebForms) SaveIndex

func (w *WebForms) SaveIndex(inputPlace string, key ...string)

func (*WebForms) SaveLabel

func (w *WebForms) SaveLabel(inputPlace string, key ...string)

func (*WebForms) SaveName

func (w *WebForms) SaveName(inputPlace string, key ...string)

func (*WebForms) SaveNodeLength

func (w *WebForms) SaveNodeLength(inputPlace string, key ...string)

func (*WebForms) SaveOuterText

func (w *WebForms) SaveOuterText(inputPlace string, key ...string)

func (*WebForms) SaveReadOnly

func (w *WebForms) SaveReadOnly(inputPlace string, key ...string)

func (*WebForms) SaveSelectedIndex

func (w *WebForms) SaveSelectedIndex(inputPlace string, key ...string)

func (*WebForms) SaveState

func (w *WebForms) SaveState(path ...string)

func (*WebForms) SaveStyle

func (w *WebForms) SaveStyle(inputPlace string, key ...string)

func (*WebForms) SaveText

func (w *WebForms) SaveText(inputPlace string, key ...string)

func (*WebForms) SaveTextAlign

func (w *WebForms) SaveTextAlign(inputPlace string, key ...string)

func (*WebForms) SaveTextLength

func (w *WebForms) SaveTextLength(inputPlace string, key ...string)

func (*WebForms) SaveTitle

func (w *WebForms) SaveTitle(inputPlace string, key ...string)

func (*WebForms) SaveUrl

func (w *WebForms) SaveUrl(url string, fetchScript ...bool)

func (*WebForms) SaveValue

func (w *WebForms) SaveValue(inputPlace string, key ...string)

func (*WebForms) SaveValueLength

func (w *WebForms) SaveValueLength(inputPlace string, key ...string)

func (*WebForms) SaveVisible

func (w *WebForms) SaveVisible(inputPlace string, key ...string)

func (*WebForms) SaveWidth

func (w *WebForms) SaveWidth(inputPlace string, key ...string)

func (*WebForms) ScrollTo

func (w *WebForms) ScrollTo(x any, y any)

func (*WebForms) ServiceWorkerDeleteDynamicCache

func (w *WebForms) ServiceWorkerDeleteDynamicCache(path ...string)

func (*WebForms) ServiceWorkerDeleteRoute

func (w *WebForms) ServiceWorkerDeleteRoute(path ...string)

Delete All Route And Alias

func (*WebForms) ServiceWorkerDeleteRouteAlias

func (w *WebForms) ServiceWorkerDeleteRouteAlias(path ...string)

func (*WebForms) ServiceWorkerDynamicCache

func (w *WebForms) ServiceWorkerDynamicCache(path string, seconds ...any)

func (*WebForms) ServiceWorkerDynamicCacheTTLUpdate

func (w *WebForms) ServiceWorkerDynamicCacheTTLUpdate(path string, seconds ...any)

func (*WebForms) ServiceWorkerPreCacheStatic

func (w *WebForms) ServiceWorkerPreCacheStatic(pathList []string)

func (*WebForms) ServiceWorkerRegister

func (w *WebForms) ServiceWorkerRegister(path ...string)

Service Worker To Use Service Worker, You Need To Add The Elanat Dedicated Module (service-worker.js) On The Client Side

func (*WebForms) ServiceWorkerRouteAlias

func (w *WebForms) ServiceWorkerRouteAlias(path string, to string)

func (*WebForms) ServiceWorkerRouteSet

func (w *WebForms) ServiceWorkerRouteSet(path string, routeType string, cacheDynamic ...bool)

func (*WebForms) SetAttribute

func (w *WebForms) SetAttribute(inputPlace string, attribute string, value ...string)

func (*WebForms) SetBackgroundColor

func (w *WebForms) SetBackgroundColor(inputPlace string, color string)

func (*WebForms) SetCache

func (w *WebForms) SetCache(second ...any)

Calling the SetCache Method Causes Action Control Requests Triggered by events using the GET, POST, PUT, PATCH, DELETE, and OPTIONS Methods, as well as Requests Triggered by the Send event, to be Cached, so the Request will not be Sent to the Server Again.

func (*WebForms) SetCheckBoxTag

func (w *WebForms) SetCheckBoxTag(inputPlace string, text string, value string, checked ...bool)

func (*WebForms) SetChecked

func (w *WebForms) SetChecked(inputPlace string, checked ...bool)

func (*WebForms) SetCheckedIndex

func (w *WebForms) SetCheckedIndex(inputPlace string, index any, checked bool)

func (*WebForms) SetCheckedValue

func (w *WebForms) SetCheckedValue(inputPlace string, value string, checked bool)

func (*WebForms) SetChecksum

func (w *WebForms) SetChecksum()

func (*WebForms) SetClass

func (w *WebForms) SetClass(inputPlace string, class string)

func (*WebForms) SetCommentEvent

func (w *WebForms) SetCommentEvent(inputPlace string, htmlEvent string, args ...any)

func (*WebForms) SetCommentEventListener

func (w *WebForms) SetCommentEventListener(inputPlace string, htmlEventListener string, args ...any)

func (*WebForms) SetCookie

func (w *WebForms) SetCookie(key string, value string, seconds any, path ...string)

Cookie

func (*WebForms) SetDeleteEvent

func (w *WebForms) SetDeleteEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) SetDeleteEventListener

func (w *WebForms) SetDeleteEventListener(inputPlace string, htmlEventListener string, args ...string)

func (*WebForms) SetDisabled

func (w *WebForms) SetDisabled(inputPlace string, disabled bool)

func (*WebForms) SetFocus

func (w *WebForms) SetFocus(inputPlace string, focus bool)

func (*WebForms) SetFontBold

func (w *WebForms) SetFontBold(inputPlace string, bold bool)

func (*WebForms) SetFontName

func (w *WebForms) SetFontName(inputPlace string, name string)

func (*WebForms) SetFontSize

func (w *WebForms) SetFontSize(inputPlace string, size any)

func (*WebForms) SetFrontEvent

func (w *WebForms) SetFrontEvent(inputPlace string, htmlEvent string, modulePath string, args ...any)

func (*WebForms) SetFrontEventListener

func (w *WebForms) SetFrontEventListener(inputPlace string, htmlEventListener string, modulePath string, args ...any)

func (*WebForms) SetGetEvent

func (w *WebForms) SetGetEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) SetGetEventListener

func (w *WebForms) SetGetEventListener(inputPlace string, htmlEventListener string, args ...string)

func (*WebForms) SetHash

func (w *WebForms) SetHash()

Hash And Checksum

func (*WebForms) SetHeadEvent

func (w *WebForms) SetHeadEvent(inputPlace string, htmlEvent string, path ...string)

func (*WebForms) SetHeadEventListener

func (w *WebForms) SetHeadEventListener(inputPlace string, htmlEventListener string, path ...string)

func (*WebForms) SetHeadTitle

func (w *WebForms) SetHeadTitle(title string)

func (*WebForms) SetHeight

func (w *WebForms) SetHeight(inputPlace string, height any)

func (*WebForms) SetId

func (w *WebForms) SetId(inputPlace string, id string)

Set Creates the Data if it does not exist; otherwise, Replaces the Existing Value with the New Value.

func (*WebForms) SetLabel

func (w *WebForms) SetLabel(inputPlace string, label string)

func (*WebForms) SetMasterPagesEvent

func (w *WebForms) SetMasterPagesEvent(inputPlace string, htmlEvent string, outputPlace ...string)

func (*WebForms) SetMasterPagesEventListener

func (w *WebForms) SetMasterPagesEventListener(inputPlace string, htmlEventListener string, outputPlace ...string)

func (*WebForms) SetMaxLength

func (w *WebForms) SetMaxLength(inputPlace string, length any)

func (*WebForms) SetMethodEvent

func (w *WebForms) SetMethodEvent(inputPlace string, htmlEvent string, methodName string, args ...any)

func (*WebForms) SetMethodEventListener

func (w *WebForms) SetMethodEventListener(inputPlace string, htmlEventListener string, methodName string, args ...any)

func (*WebForms) SetMinLength

func (w *WebForms) SetMinLength(inputPlace string, length any)

func (*WebForms) SetModuleMethodEvent

func (w *WebForms) SetModuleMethodEvent(inputPlace string, htmlEvent string, methodName string, args ...any)

func (*WebForms) SetModuleMethodEventListener

func (w *WebForms) SetModuleMethodEventListener(inputPlace string, htmlEventListener string, methodName string, args ...any)

func (*WebForms) SetMorph

func (w *WebForms) SetMorph(inputPlace string, tag string)

func (*WebForms) SetMorphByOutputPlace

func (w *WebForms) SetMorphByOutputPlace(inputPlace string, outputPlace string)

func (*WebForms) SetName

func (w *WebForms) SetName(inputPlace string, name string)

func (*WebForms) SetOptionTag

func (w *WebForms) SetOptionTag(inputPlace string, text string, value string, selected ...bool)

func (*WebForms) SetOptionsEvent

func (w *WebForms) SetOptionsEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) SetOptionsEventListener

func (w *WebForms) SetOptionsEventListener(inputPlace string, htmlEventListener string, args ...string)

func (*WebForms) SetPatchEvent

func (w *WebForms) SetPatchEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) SetPatchEventListener

func (w *WebForms) SetPatchEventListener(inputPlace string, htmlEventListener string, args ...string)

func (*WebForms) SetPostEvent

func (w *WebForms) SetPostEvent(inputPlace string, htmlEvent string, outputPlace ...string)

func (*WebForms) SetPostEventAddView

func (w *WebForms) SetPostEventAddView(inputPlace string, htmlEvent string)

func (*WebForms) SetPostEventListener

func (w *WebForms) SetPostEventListener(inputPlace string, htmlEventListener string, outputPlace ...string)

func (*WebForms) SetPostEventListenerAddView

func (w *WebForms) SetPostEventListenerAddView(inputPlace string, htmlEventListener string)

func (*WebForms) SetPreventDefaultEvent

func (w *WebForms) SetPreventDefaultEvent(inputPlace string, htmlEvent string)

func (*WebForms) SetPreventDefaultEventListener

func (w *WebForms) SetPreventDefaultEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) SetPutEvent

func (w *WebForms) SetPutEvent(inputPlace string, htmlEvent string, args ...string)

func (*WebForms) SetPutEventListener

func (w *WebForms) SetPutEventListener(inputPlace string, htmlEventListener string, args ...string)

func (*WebForms) SetReadOnly

func (w *WebForms) SetReadOnly(inputPlace string, readOnly bool)

func (*WebForms) SetReflection

func (w *WebForms) SetReflection(inputPlace string, tag string)

func (*WebForms) SetReflectionByOutputPlace

func (w *WebForms) SetReflectionByOutputPlace(inputPlace string, outputPlace string)

func (*WebForms) SetSSEEvent

func (w *WebForms) SetSSEEvent(inputPlace string, htmlEvent string, path string, args ...any)

func (*WebForms) SetSSEEventListener

func (w *WebForms) SetSSEEventListener(inputPlace string, htmlEventListener string, path string, args ...any)

func (*WebForms) SetSave

func (w *WebForms) SetSave()

Calling the SetSave Method Causes Action Control Requests Triggered by Events Using the GET, POST, PUT, PATCH, DELETE, and OPTIONS Methods, as well as Requests Triggered by the Send Event, to be Temporarily Saved on the Active Page, so the Request will not be Sent to the Server Again.

func (*WebForms) SetSelectedIndex

func (w *WebForms) SetSelectedIndex(inputPlace string, index any)

func (*WebForms) SetSelectedValue

func (w *WebForms) SetSelectedValue(inputPlace string, value string)

func (*WebForms) SetSendEvent

func (w *WebForms) SetSendEvent(inputPlace string, htmlEvent string, data string, args ...any)

IsMultiPart: If this value is true, the data will be sent based on the Form and with the "content" key.

func (*WebForms) SetSendEventListener

func (w *WebForms) SetSendEventListener(inputPlace string, htmlEventListener string, data string, args ...any)

func (*WebForms) SetStopPropagationEvent

func (w *WebForms) SetStopPropagationEvent(inputPlace string, htmlEvent string)

func (*WebForms) SetStopPropagationEventListener

func (w *WebForms) SetStopPropagationEventListener(inputPlace string, htmlEventListener string)

func (*WebForms) SetStyle

func (w *WebForms) SetStyle(inputPlace string, args ...string)

func (*WebForms) SetText

func (w *WebForms) SetText(inputPlace string, text string)

func (*WebForms) SetTextAlign

func (w *WebForms) SetTextAlign(inputPlace string, align string)

func (*WebForms) SetTextColor

func (w *WebForms) SetTextColor(inputPlace string, color string)

func (*WebForms) SetTitle

func (w *WebForms) SetTitle(inputPlace string, title string)

func (*WebForms) SetValue

func (w *WebForms) SetValue(inputPlace string, value string)

func (*WebForms) SetVisible

func (w *WebForms) SetVisible(inputPlace string, visible bool)

func (*WebForms) SetWasmEvent

func (w *WebForms) SetWasmEvent(inputPlace string, htmlEvent string, wasmLanguage string, wasmURL string, methodName string, args ...any)

func (*WebForms) SetWasmEventListener

func (w *WebForms) SetWasmEventListener(inputPlace string, htmlEventListener string, wasmLanguage string, wasmURL string, methodName string, args ...any)

func (*WebForms) SetWebSocketEvent

func (w *WebForms) SetWebSocketEvent(inputPlace string, htmlEvent string, path string)

func (*WebForms) SetWebSocketEventListener

func (w *WebForms) SetWebSocketEventListener(inputPlace string, htmlEventListener string, path string)

func (*WebForms) SetWidth

func (w *WebForms) SetWidth(inputPlace string, width any)

func (*WebForms) StartBracket

func (w *WebForms) StartBracket()

func (*WebForms) StartIndex

func (w *WebForms) StartIndex(name ...string)

Index

func (*WebForms) StartState

func (w *WebForms) StartState()

This Index Is Automatically Run After Changing The Browser History (Back And Forward Buttons)

func (*WebForms) StartTransientDOM

func (w *WebForms) StartTransientDOM(inputPlace string)

Start

func (*WebForms) SwapTag

func (w *WebForms) SwapTag(inputPlace string, outputPlace string)

Tag

func (*WebForms) Then

func (w *WebForms) Then(newForm *WebForms) *WebForms

Used Then In Condition And Loop Methods

func (*WebForms) ThenConfigure

func (w *WebForms) ThenConfigure(configure func(*WebForms)) *WebForms

func (*WebForms) TriggerEvent

func (w *WebForms) TriggerEvent(inputPlace string, htmlEventListener string, constructorName ...string)

Event ConstructorName: mouseevent, keyboardevent, uievent, focusevent, inputevent, event All Method in "Event" Section Only Support Dynamic Args Once. To Support Invoking Dynamic Arguments on a Momentary Basis, Use "EventListener" Section Methods.

func (*WebForms) UnloadModule

func (w *WebForms) UnloadModule(modulePath string)

func (*WebForms) UpdateINI

func (w *WebForms) UpdateINI(key string, path string, value string, isINILike bool)

func (*WebForms) UpdateJSON

func (w *WebForms) UpdateJSON(key string, path string, value string)

func (*WebForms) UpdateTexLine

func (w *WebForms) UpdateTexLine(key string, line string, text string)

func (*WebForms) UpdateTexLineInt

func (w *WebForms) UpdateTexLineInt(key string, line int, text string)

func (*WebForms) UpdateVariable

func (w *WebForms) UpdateVariable(key string, value string)

func (*WebForms) UpdateXML

func (w *WebForms) UpdateXML(key string, path string, value string)

func (*WebForms) UseOnlyChangeUpdate

func (w *WebForms) UseOnlyChangeUpdate(inputPlace string)

func (*WebForms) UseWebSocket

func (w *WebForms) UseWebSocket(inputPlace string)

Use InputPlace Using Only For form Element

Jump to