Documentation
¶
Index ¶
- Constants
- Variables
- func AppendFetchReplace(text string, searchValue string, value string) string
- func Child(text string, value string) string
- func Criteria(text string, value string) string
- func LineBreak(text string, encodeLine bool) string
- func Parent(text string) string
- func ToJSObject(text string) string
- func ToJSReturnObject(text string) string
- func ToJSString(text string) string
- type OutputPlace
- func (OutputPlace) AllAttributes(name string) string
- func (OutputPlace) AllAttributesValue(name string, value string, operator ...rune) string
- func (OutputPlace) AllChild() string
- func (OutputPlace) AllClasses(class string) string
- func (OutputPlace) AllNames(name string) string
- func (OutputPlace) AllTags(tag string) string
- func (OutputPlace) Attribute(name string) string
- func (OutputPlace) AttributeIndex(name string, index int) string
- func (OutputPlace) AttributeValue(name string, value string, operator ...rune) string
- func (OutputPlace) AttributeValueIndex(name string, value string, index int, operator ...rune) string
- func (OutputPlace) Child() string
- func (OutputPlace) ChildIndex(index int) string
- func (OutputPlace) Class(class string) string
- func (OutputPlace) ClassIndex(class string, index int) string
- func (OutputPlace) Id(id string) string
- func (OutputPlace) Name(name string) string
- func (OutputPlace) NameIndex(name string, index int) string
- func (OutputPlace) Query(query string) string
- func (OutputPlace) QueryAll(query string) string
- func (OutputPlace) Tag(tag string) string
- func (OutputPlace) TagIndex(tag string, index int) string
- type Security
- type WebForms
- func (w *WebForms) AddAttribute(inputPlace string, attribute string, args ...any)
- func (w *WebForms) AddCacheValue(cacheKey string, value string)
- func (w *WebForms) AddCheckBoxTag(inputPlace string, text string, value string, checked ...bool)
- func (w *WebForms) AddClass(inputPlace string, class string)
- func (w *WebForms) AddHidden(inputPlace string, name string, value string, id ...string)
- func (w *WebForms) AddINI(key string, path string, value string, isINILike bool)
- func (w *WebForms) AddId(inputPlace string, id string)
- func (w *WebForms) AddJSON(key string, path string, value string)
- func (w *WebForms) AddLabel(inputPlace string, label string)
- func (w *WebForms) AddLine(name string, value string)
- func (w *WebForms) AddName(inputPlace string, name string)
- func (w *WebForms) AddOptionTag(inputPlace string, text string, value string, selected ...bool)
- func (w *WebForms) AddSaveValue(cacheKey string, value string)
- func (w *WebForms) AddState(path ...string)
- func (w *WebForms) AddStyle(inputPlace string, args ...string)
- func (w *WebForms) AddTag(inputPlace string, tagName string, id ...string)
- func (w *WebForms) AddTagAfter(inputPlace string, tagName string, id ...string)
- func (w *WebForms) AddTagBefore(inputPlace string, tagName string, id ...string)
- func (w *WebForms) AddTagToUp(inputPlace string, tagName string, id ...string)
- func (w *WebForms) AddText(inputPlace string, text string)
- func (w *WebForms) AddTextLine(key string, line string, text string)
- func (w *WebForms) AddTextLineInt(key string, line int, text string)
- func (w *WebForms) AddTextToUp(inputPlace string, text string)
- func (w *WebForms) AddTitle(inputPlace string, title string)
- func (w *WebForms) AddValue(inputPlace string, value string)
- func (w *WebForms) AddVariable(key string, value string)
- func (w *WebForms) AddWebSocket(path string)
- func (w *WebForms) AddXML(key string, path string, name string, value string)
- func (w *WebForms) Alert(text string, args ...string)
- func (w *WebForms) AppendCacheValue(cacheKey string, value string)
- func (w *WebForms) AppendForm(form *WebForms)
- func (w *WebForms) AppendSaveValue(cacheKey string, value string)
- func (w *WebForms) AssertEqual(inputPlace string, tag string)
- func (w *WebForms) AssertEqualByOutputPlace(inputPlace string, outputPlace string)
- func (w *WebForms) AssignConfirmEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) AssignDelay(miliSecond int, index ...int)
- func (w *WebForms) AssignDelayChange(miliSecond int, index ...int)
- func (w *WebForms) AssignInterval(miliSecond int, id string, index ...int)
- func (w *WebForms) AssignIntervalChange(miliSecond int, id string, index ...int)
- func (w *WebForms) AssignRepeat(count int, index ...int)
- func (w *WebForms) AssignRepeatChange(count int, index ...int)
- func (w *WebForms) AssignReplace(searchValue string, value string, index int)
- func (w *WebForms) Async() *WebForms
- func (w *WebForms) BindINIToTemplate(inputPlace string, iniText string, path string, pattern string, ...)
- func (w *WebForms) BindJSONToTemplate(inputPlace string, jsonText string, path string, pattern string, ...)
- func (w *WebForms) BindXMLToTemplate(inputPlace string, xmlText string, path string, pattern string, ...)
- func (w *WebForms) Break()
- func (w *WebForms) CacheAttribute(inputPlace string, attribute string, key ...string)
- func (w *WebForms) CacheClass(inputPlace string, key ...string)
- func (w *WebForms) CacheHeight(inputPlace string, key ...string)
- func (w *WebForms) CacheId(inputPlace string, key ...string)
- func (w *WebForms) CacheIndex(inputPlace string, key ...string)
- func (w *WebForms) CacheLabel(inputPlace string, key ...string)
- func (w *WebForms) CacheName(inputPlace string, key ...string)
- func (w *WebForms) CacheNodeLength(inputPlace string, key ...string)
- func (w *WebForms) CacheOuterText(inputPlace string, key ...string)
- func (w *WebForms) CacheReadOnly(inputPlace string, key ...string)
- func (w *WebForms) CacheSelectedIndex(inputPlace string, key ...string)
- func (w *WebForms) CacheStyle(inputPlace string, key ...string)
- func (w *WebForms) CacheText(inputPlace string, key ...string)
- func (w *WebForms) CacheTextAlign(inputPlace string, key ...string)
- func (w *WebForms) CacheTextLength(inputPlace string, key ...string)
- func (w *WebForms) CacheTitle(inputPlace string, key ...string)
- func (w *WebForms) CacheUrl(url string, fetchScript ...any)
- func (w *WebForms) CacheValue(inputPlace string, key ...string)
- func (w *WebForms) CacheValueLength(inputPlace string, key ...string)
- func (w *WebForms) CacheVisible(inputPlace string, key ...string)
- func (w *WebForms) CacheWidth(inputPlace string, key ...string)
- func (w *WebForms) CallCommentBack(index ...any)
- func (w *WebForms) CallDeleteBack(path string, args ...any)
- func (w *WebForms) CallFront(modulePath string, args ...any)
- func (w *WebForms) CallGetBack(path string, args ...any)
- func (w *WebForms) CallHeadBack(path string, useCurrentEvent ...bool)
- func (w *WebForms) CallMethod(methodName string, args ...any)
- func (w *WebForms) CallModuleMethod(methodName string, args ...any)
- func (w *WebForms) CallOptionsBack(path string, args ...any)
- func (w *WebForms) CallPatchBack(path string, args ...any)
- func (w *WebForms) CallPostBack(formInputPlace string, outputPlace ...string)
- func (w *WebForms) CallPutBack(path string, args ...any)
- func (w *WebForms) CallSSEBack(path string, args ...any)
- func (w *WebForms) CallScript(scriptText string)
- func (w *WebForms) CallSendBack(path string, method string, isMultiPart bool, contentType string, data string, ...)
- func (w *WebForms) CallWasmBack(wasmLanguage string, wasmUrl string, methodName string, args ...any)
- func (w *WebForms) CallWebSocketBack(path string, useCurrentEvent ...bool)
- func (w *WebForms) ChangeOption(name string, value string)
- func (w *WebForms) ChangeUrl(url string)
- func (w *WebForms) ChecksumCalculation(text string) string
- func (w *WebForms) Clean()
- func (w *WebForms) ClipboardWriteText(text string)
- func (w *WebForms) ConfirmIsFalseAccept(text string, typ string, title string, okText string, cancelText string, ...) *WebForms
- func (w *WebForms) ConfirmIsTrueAccept(text string, typ string, title string, okText string, cancelText string, ...) *WebForms
- func (w *WebForms) ConsoleMessage(text string, typ ...string)
- func (w *WebForms) ConsoleMessageAssert(text string, condition string)
- func (w *WebForms) CreateCustomDOMEvent(inputPlace string, eventName string, watch string, key string, compare string, ...)
- func (w *WebForms) CreateDebugger(pause ...bool)
- func (w *WebForms) CreateFormatStorage(key string, data string)
- func (w *WebForms) Decrease(inputPlace string, value float32)
- func (w *WebForms) DecreaseFontSize(inputPlace string, value any)
- func (w *WebForms) DecreaseHeight(inputPlace string, value any)
- func (w *WebForms) DecreaseMaxLength(inputPlace string, value any)
- func (w *WebForms) DecreaseMinLength(inputPlace string, value any)
- func (w *WebForms) DecreaseValue(inputPlace string, value any)
- func (w *WebForms) DecreaseVariable(key string, value int)
- func (w *WebForms) DecreaseWidth(inputPlace string, value any)
- func (w *WebForms) Delay(milliseconds string)
- func (w *WebForms) DelayInt(milliseconds int)
- func (w *WebForms) Delete(inputPlace string)
- func (w *WebForms) DeleteAllCheckBoxTag(inputPlace string)
- func (w *WebForms) DeleteAllOptionTag(inputPlace string)
- func (w *WebForms) DeleteAllState()
- func (w *WebForms) DeleteAttribute(inputPlace string, attribute string)
- func (w *WebForms) DeleteCheckBoxTag(inputPlace string, value string)
- func (w *WebForms) DeleteClass(inputPlace string, className string)
- func (w *WebForms) DeleteFormatStorage(key string)
- func (w *WebForms) DeleteINI(key string, path string, isINILike ...bool)
- func (w *WebForms) DeleteId(inputPlace string)
- func (w *WebForms) DeleteInterval(id string)
- func (w *WebForms) DeleteJSON(key string, path string)
- func (w *WebForms) DeleteLabel(inputPlace string)
- func (w *WebForms) DeleteModuleMethod(methodName string)
- func (w *WebForms) DeleteName(inputPlace string)
- func (w *WebForms) DeleteOptionTag(inputPlace string, value string)
- func (w *WebForms) DeleteParent(inputPlace string)
- func (w *WebForms) DeleteState(path ...string)
- func (w *WebForms) DeleteStyle(inputPlace string, styleName string)
- func (w *WebForms) DeleteText(inputPlace string)
- func (w *WebForms) DeleteTextLine(key string, line string)
- func (w *WebForms) DeleteTextLineInt(key string, line int)
- func (w *WebForms) DeleteTitle(inputPlace string)
- func (w *WebForms) DeleteValue(inputPlace string)
- func (w *WebForms) DeleteVariable(key string)
- func (w *WebForms) DeleteWebSocket(path string)
- func (w *WebForms) DeleteXML(key string, path string)
- func (w *WebForms) DisconnectAllSSE()
- func (w *WebForms) DisconnectSSE(path string)
- func (w *WebForms) ElementExists(inputPlace string, interval int) *WebForms
- func (w *WebForms) ElementNotExists(inputPlace string, interval int) *WebForms
- func (w *WebForms) Else() *WebForms
- func (w *WebForms) EnableReachedElementEvent(inputPlace string, once bool, enable ...bool)
- func (w *WebForms) EnableScrollBottomEvent(enable ...bool)
- func (w *WebForms) EnableWebSocket(enable ...bool)
- func (w *WebForms) EnableWebSocketOnce()
- func (w *WebForms) EndBracket()
- func (w *WebForms) EndTransientDOM()
- func (w *WebForms) Exist(value string, interval int) *WebForms
- func (w *WebForms) ExportToHtmlComment(addLine bool) string
- func (w *WebForms) ExportToLineBreak(src string) string
- func (w *WebForms) ForEach(path string, in string, key string) *WebForms
- func (w *WebForms) GetChecksum() string
- func (w *WebForms) GetFormsActionData() string
- func (w *WebForms) GetFormsActionDataLineBreak() string
- func (w *WebForms) GetwebFormsData() string
- func (w *WebForms) GoTo(line string, repeat ...string)
- func (w *WebForms) GoToIndex(index string, repeat ...int)
- func (w *WebForms) GoToInt(line int, repeat ...int)
- func (w *WebForms) HistoryGo(steps any)
- func (w *WebForms) Include(text string, value string, interval int) *WebForms
- func (w *WebForms) Increase(inputPlace string, value float32)
- func (w *WebForms) IncreaseFontSize(inputPlace string, value any)
- func (w *WebForms) IncreaseHeight(inputPlace string, value any)
- func (w *WebForms) IncreaseMaxLength(inputPlace string, value any)
- func (w *WebForms) IncreaseMinLength(inputPlace string, value any)
- func (w *WebForms) IncreaseValue(inputPlace string, value any)
- func (w *WebForms) IncreaseVariable(key string, value string)
- func (w *WebForms) IncreaseVariableInt(key string, value int)
- func (w *WebForms) IncreaseWidth(inputPlace string, value any)
- func (w *WebForms) Inject(value string) string
- func (w *WebForms) InsertAttribute(inputPlace string, attribute string, args ...any)
- func (w *WebForms) InsertCacheValue(cacheKey string, value string)
- func (w *WebForms) InsertCheckBoxTag(inputPlace string, text string, value string, checked ...bool)
- func (w *WebForms) InsertClass(inputPlace string, class string)
- func (w *WebForms) InsertId(inputPlace string, id string)
- func (w *WebForms) InsertLabel(inputPlace string, label string)
- func (w *WebForms) InsertName(inputPlace string, name string)
- func (w *WebForms) InsertOptionTag(inputPlace string, text string, value string, selected ...bool)
- func (w *WebForms) InsertSaveValue(cacheKey string, value string)
- func (w *WebForms) InsertStyle(inputPlace string, args ...string)
- func (w *WebForms) InsertText(inputPlace string, text string)
- func (w *WebForms) InsertTitle(inputPlace string, title string)
- func (w *WebForms) InsertValue(inputPlace string, value string)
- func (w *WebForms) IsEqualTo(firstValue string, secondValue string, interval int) *WebForms
- func (w *WebForms) IsFalse(value string, interval int) *WebForms
- func (w *WebForms) IsGreaterThan(firstValue string, secondValue string, interval int) *WebForms
- func (w *WebForms) IsLessThan(firstValue string, secondValue string, interval int) *WebForms
- func (w *WebForms) IsMatchMedia(value string, interval int) *WebForms
- func (w *WebForms) IsNotEqualTo(firstValue string, secondValue string, interval int) *WebForms
- func (w *WebForms) IsNotMatchMedia(value string, interval int) *WebForms
- func (w *WebForms) IsRegexMatch(value string, pattern string, interval int) *WebForms
- func (w *WebForms) IsRegexNotMatch(value string, pattern string, interval int) *WebForms
- func (w *WebForms) IsTrue(value string, interval int) *WebForms
- func (w *WebForms) LoadModule(modulePath string, methods ...[]string)
- func (w *WebForms) LoadState(path string)
- func (w *WebForms) LoadUrl(inputPlace string, url string)
- func (w *WebForms) Message(text string, args ...any)
- func (w *WebForms) NotExist(value string, interval int) *WebForms
- func (w *WebForms) NotInclude(text string, value string, interval int) *WebForms
- func (w *WebForms) Redirect(path string)
- func (w *WebForms) ReloadPage()
- func (w *WebForms) RemoveAllCache()
- func (w *WebForms) RemoveAllSave()
- func (w *WebForms) RemoveCache(cacheKey string)
- func (w *WebForms) RemoveCommentEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveCommentEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveConfirmEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveDeleteEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveDeleteEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveFrontEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveFrontEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveGetEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveGetEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveHeadEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveHeadEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveMasterPagesEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveMasterPagesEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveMethodEvent(inputPlace string, htmlEvent string, methodName string)
- func (w *WebForms) RemoveMethodEventListener(inputPlace string, htmlEventListener string, methodName string)
- func (w *WebForms) RemoveModuleMethodEvent(inputPlace string, htmlEvent string, methodName string)
- func (w *WebForms) RemoveModuleMethodEventListener(inputPlace string, htmlEventListener string, methodName string)
- func (w *WebForms) RemoveOptionsEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveOptionsEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemovePatchEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemovePatchEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemovePostEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemovePostEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemovePreventDefaultEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemovePreventDefaultEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemovePutEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemovePutEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveSSEEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveSSEEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveSave(cacheKey string)
- func (w *WebForms) RemoveSendEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveSendEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveStopPropagationEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveStopPropagationEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveWasmEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveWasmEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) RemoveWebSocketEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) RemoveWebSocketEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) Repeat(newForm *WebForms, repeat int) *WebForms
- func (w *WebForms) RepeatConfigure(configure func(*WebForms), repeat int) *WebForms
- func (w *WebForms) RepeatConfigureWithIndex(configure func(*WebForms), repeat int, index string) *WebForms
- func (w *WebForms) RepeatWithIndex(newForm *WebForms, repeat int, index string) *WebForms
- func (w *WebForms) Replace(inputPlace string, value string, newValue string, args ...bool)
- func (w *WebForms) ReplaceActionControl(searchValue string, value string, addingToUp bool)
- func (w *WebForms) ReplaceCacheValue(cacheKey string, searchValue string, value string)
- func (w *WebForms) ReplaceSaveValue(cacheKey string, searchValue string, value string)
- func (w *WebForms) ReplaceStartTag(inputPlace string, value string, newValue string)
- func (w *WebForms) ResetOption()
- func (w *WebForms) ResetOptionName(name string)
- func (w *WebForms) Response() string
- func (w *WebForms) RunActionControls(actionControls string, withoutWebFormsSection ...any)
- func (w *WebForms) SaveAttribute(inputPlace string, attribute string, key ...string)
- func (w *WebForms) SaveClass(inputPlace string, key ...string)
- func (w *WebForms) SaveHeight(inputPlace string, key ...string)
- func (w *WebForms) SaveId(inputPlace string, key ...string)
- func (w *WebForms) SaveIndex(inputPlace string, key ...string)
- func (w *WebForms) SaveLabel(inputPlace string, key ...string)
- func (w *WebForms) SaveName(inputPlace string, key ...string)
- func (w *WebForms) SaveNodeLength(inputPlace string, key ...string)
- func (w *WebForms) SaveOuterText(inputPlace string, key ...string)
- func (w *WebForms) SaveReadOnly(inputPlace string, key ...string)
- func (w *WebForms) SaveSelectedIndex(inputPlace string, key ...string)
- func (w *WebForms) SaveState(path ...string)
- func (w *WebForms) SaveStyle(inputPlace string, key ...string)
- func (w *WebForms) SaveText(inputPlace string, key ...string)
- func (w *WebForms) SaveTextAlign(inputPlace string, key ...string)
- func (w *WebForms) SaveTextLength(inputPlace string, key ...string)
- func (w *WebForms) SaveTitle(inputPlace string, key ...string)
- func (w *WebForms) SaveUrl(url string, fetchScript ...bool)
- func (w *WebForms) SaveValue(inputPlace string, key ...string)
- func (w *WebForms) SaveValueLength(inputPlace string, key ...string)
- func (w *WebForms) SaveVisible(inputPlace string, key ...string)
- func (w *WebForms) SaveWidth(inputPlace string, key ...string)
- func (w *WebForms) ScrollTo(x any, y any)
- func (w *WebForms) ServiceWorkerDeleteDynamicCache(path ...string)
- func (w *WebForms) ServiceWorkerDeleteRoute(path ...string)
- func (w *WebForms) ServiceWorkerDeleteRouteAlias(path ...string)
- func (w *WebForms) ServiceWorkerDynamicCache(path string, seconds ...any)
- func (w *WebForms) ServiceWorkerDynamicCacheTTLUpdate(path string, seconds ...any)
- func (w *WebForms) ServiceWorkerPreCacheStatic(pathList []string)
- func (w *WebForms) ServiceWorkerRegister(path ...string)
- func (w *WebForms) ServiceWorkerRouteAlias(path string, to string)
- func (w *WebForms) ServiceWorkerRouteSet(path string, routeType string, cacheDynamic ...bool)
- func (w *WebForms) SetAttribute(inputPlace string, attribute string, value ...string)
- func (w *WebForms) SetBackgroundColor(inputPlace string, color string)
- func (w *WebForms) SetCache(second ...any)
- func (w *WebForms) SetCheckBoxTag(inputPlace string, text string, value string, checked ...bool)
- func (w *WebForms) SetChecked(inputPlace string, checked ...bool)
- func (w *WebForms) SetCheckedIndex(inputPlace string, index any, checked bool)
- func (w *WebForms) SetCheckedValue(inputPlace string, value string, checked bool)
- func (w *WebForms) SetChecksum()
- func (w *WebForms) SetClass(inputPlace string, class string)
- func (w *WebForms) SetCommentEvent(inputPlace string, htmlEvent string, args ...any)
- func (w *WebForms) SetCommentEventListener(inputPlace string, htmlEventListener string, args ...any)
- func (w *WebForms) SetCookie(key string, value string, seconds any, path ...string)
- func (w *WebForms) SetDeleteEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) SetDeleteEventListener(inputPlace string, htmlEventListener string, args ...string)
- func (w *WebForms) SetDisabled(inputPlace string, disabled bool)
- func (w *WebForms) SetFocus(inputPlace string, focus bool)
- func (w *WebForms) SetFontBold(inputPlace string, bold bool)
- func (w *WebForms) SetFontName(inputPlace string, name string)
- func (w *WebForms) SetFontSize(inputPlace string, size any)
- func (w *WebForms) SetFrontEvent(inputPlace string, htmlEvent string, modulePath string, args ...any)
- func (w *WebForms) SetFrontEventListener(inputPlace string, htmlEventListener string, modulePath string, args ...any)
- func (w *WebForms) SetGetEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) SetGetEventListener(inputPlace string, htmlEventListener string, args ...string)
- func (w *WebForms) SetHash()
- func (w *WebForms) SetHeadEvent(inputPlace string, htmlEvent string, path ...string)
- func (w *WebForms) SetHeadEventListener(inputPlace string, htmlEventListener string, path ...string)
- func (w *WebForms) SetHeadTitle(title string)
- func (w *WebForms) SetHeight(inputPlace string, height any)
- func (w *WebForms) SetId(inputPlace string, id string)
- func (w *WebForms) SetLabel(inputPlace string, label string)
- func (w *WebForms) SetMasterPagesEvent(inputPlace string, htmlEvent string, outputPlace ...string)
- func (w *WebForms) SetMasterPagesEventListener(inputPlace string, htmlEventListener string, outputPlace ...string)
- func (w *WebForms) SetMaxLength(inputPlace string, length any)
- func (w *WebForms) SetMethodEvent(inputPlace string, htmlEvent string, methodName string, args ...any)
- func (w *WebForms) SetMethodEventListener(inputPlace string, htmlEventListener string, methodName string, args ...any)
- func (w *WebForms) SetMinLength(inputPlace string, length any)
- func (w *WebForms) SetModuleMethodEvent(inputPlace string, htmlEvent string, methodName string, args ...any)
- func (w *WebForms) SetModuleMethodEventListener(inputPlace string, htmlEventListener string, methodName string, args ...any)
- func (w *WebForms) SetMorph(inputPlace string, tag string)
- func (w *WebForms) SetMorphByOutputPlace(inputPlace string, outputPlace string)
- func (w *WebForms) SetName(inputPlace string, name string)
- func (w *WebForms) SetOptionTag(inputPlace string, text string, value string, selected ...bool)
- func (w *WebForms) SetOptionsEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) SetOptionsEventListener(inputPlace string, htmlEventListener string, args ...string)
- func (w *WebForms) SetPatchEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) SetPatchEventListener(inputPlace string, htmlEventListener string, args ...string)
- func (w *WebForms) SetPostEvent(inputPlace string, htmlEvent string, outputPlace ...string)
- func (w *WebForms) SetPostEventAddView(inputPlace string, htmlEvent string)
- func (w *WebForms) SetPostEventListener(inputPlace string, htmlEventListener string, outputPlace ...string)
- func (w *WebForms) SetPostEventListenerAddView(inputPlace string, htmlEventListener string)
- func (w *WebForms) SetPreventDefaultEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) SetPreventDefaultEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) SetPutEvent(inputPlace string, htmlEvent string, args ...string)
- func (w *WebForms) SetPutEventListener(inputPlace string, htmlEventListener string, args ...string)
- func (w *WebForms) SetReadOnly(inputPlace string, readOnly bool)
- func (w *WebForms) SetReflection(inputPlace string, tag string)
- func (w *WebForms) SetReflectionByOutputPlace(inputPlace string, outputPlace string)
- func (w *WebForms) SetSSEEvent(inputPlace string, htmlEvent string, path string, args ...any)
- func (w *WebForms) SetSSEEventListener(inputPlace string, htmlEventListener string, path string, args ...any)
- func (w *WebForms) SetSave()
- func (w *WebForms) SetSelectedIndex(inputPlace string, index any)
- func (w *WebForms) SetSelectedValue(inputPlace string, value string)
- func (w *WebForms) SetSendEvent(inputPlace string, htmlEvent string, data string, args ...any)
- func (w *WebForms) SetSendEventListener(inputPlace string, htmlEventListener string, data string, args ...any)
- func (w *WebForms) SetStopPropagationEvent(inputPlace string, htmlEvent string)
- func (w *WebForms) SetStopPropagationEventListener(inputPlace string, htmlEventListener string)
- func (w *WebForms) SetStyle(inputPlace string, args ...string)
- func (w *WebForms) SetText(inputPlace string, text string)
- func (w *WebForms) SetTextAlign(inputPlace string, align string)
- func (w *WebForms) SetTextColor(inputPlace string, color string)
- func (w *WebForms) SetTitle(inputPlace string, title string)
- func (w *WebForms) SetValue(inputPlace string, value string)
- func (w *WebForms) SetVisible(inputPlace string, visible bool)
- func (w *WebForms) SetWasmEvent(inputPlace string, htmlEvent string, wasmLanguage string, wasmURL string, ...)
- func (w *WebForms) SetWasmEventListener(inputPlace string, htmlEventListener string, wasmLanguage string, ...)
- func (w *WebForms) SetWebSocketEvent(inputPlace string, htmlEvent string, path string)
- func (w *WebForms) SetWebSocketEventListener(inputPlace string, htmlEventListener string, path string)
- func (w *WebForms) SetWidth(inputPlace string, width any)
- func (w *WebForms) StartBracket()
- func (w *WebForms) StartIndex(name ...string)
- func (w *WebForms) StartState()
- func (w *WebForms) StartTransientDOM(inputPlace string)
- func (w *WebForms) SwapTag(inputPlace string, outputPlace string)
- func (w *WebForms) Then(newForm *WebForms) *WebForms
- func (w *WebForms) ThenConfigure(configure func(*WebForms)) *WebForms
- func (w *WebForms) TriggerEvent(inputPlace string, htmlEventListener string, constructorName ...string)
- func (w *WebForms) UnloadModule(modulePath string)
- func (w *WebForms) UpdateINI(key string, path string, value string, isINILike bool)
- func (w *WebForms) UpdateJSON(key string, path string, value string)
- func (w *WebForms) UpdateTexLine(key string, line string, text string)
- func (w *WebForms) UpdateTexLineInt(key string, line int, text string)
- func (w *WebForms) UpdateVariable(key string, value string)
- func (w *WebForms) UpdateXML(key string, path string, value string)
- func (w *WebForms) UseOnlyChangeUpdate(inputPlace string)
- func (w *WebForms) UseWebSocket(inputPlace string)
Constants ¶
const ( GS = string(rune(29)) US = string(rune(31)) )
const ( FetchRS = string(rune(30)) FetchUS = string(rune(31)) )
Variables ¶
var Fetch = fetch{
DateYear: "@dy",
DateMonth: "@dm",
DateDay: "@dd",
DateDate: "@dD",
DateHours: "@dh",
DateMinutes: "@di",
DateSeconds: "@ds",
DateMilliseconds: "@dl",
Space: "@sp",
AtSign: "@sa",
TabIsActive: "@da",
Href: "@wf",
PathName: "@wP",
Hash: "@wh",
Host: "@wH",
HostName: "@wn",
Port: "@wT",
Origin: "@wo",
GetSelection: "@ws",
ScrollX: "@wx",
ScrollY: "@wy",
ClipboardText: "@nC",
GeoLatitude: "@nW",
GeoLongitude: "@nO",
Language: "@nL",
IsOnLine: "@no",
UserAgent: "@na",
ScreenWidth: "@sw",
ScreenHeight: "@sh",
ScreenOrientationType: "@so",
ScreenOrientationAngle: "@sr",
TimeOrigin: "@pt",
PerformanceNow: "@pn",
Event: "@EV",
EventSerialize: "@Es",
EventKey: "@ek",
EventWhich: "@ew",
EventClientX: "@ex",
EventClientY: "@ey",
EventPageX: "@eX",
EventPageY: "@eY",
EventOffsetX: "@Ex",
EventOffsetY: "@Ey",
EventDeltaY: "@ed",
}
var HtmlEvent = htmlEvent{
OnAbort: "onabort",
OnAfterPrint: "onafterprint",
OnBeforePrint: "onbeforeprint",
OnBeforeUnload: "onbeforeunload",
OnBlur: "onblur",
OnCanPlay: "oncanplay",
OnCanPlayThrough: "oncanplaythrough",
OnChange: "onchange",
OnClick: "onclick",
OnCopy: "oncopy",
OnCut: "oncut",
OnDoubleClick: "ondblclick",
OnDrag: "ondrag",
OnDragEnd: "ondragend",
OnDragEnter: "ondragenter",
OnDragLeave: "ondragleave",
OnDragOver: "ondragover",
OnDragStart: "ondragstart",
OnDrop: "ondrop",
OnDurationChange: "ondurationchange",
OnEnded: "onended",
OnError: "onerror",
OnFocus: "onfocus",
OnFocusin: "onfocusin",
OnFocusOut: "onfocusout",
OnHashChange: "onhashchange",
OnInput: "oninput",
OnInvalid: "oninvalid",
OnKeyDown: "onkeydown",
OnKeyPress: "onkeypress",
OnKeyUp: "onkeyup",
OnLoad: "onload",
OnLoadedData: "onloadeddata",
OnLoadedMetaData: "onloadedmetadata",
OnLoadStart: "onloadstart",
OnMouseDown: "onmousedown",
OnMouseEnter: "onmouseenter",
OnMouseLeave: "onmouseleave",
OnMouseMove: "onmousemove",
OnMouseOver: "onmouseover",
OnMouseOut: "onmouseout",
OnMouseUp: "onmouseup",
OnOffline: "onoffline",
OnOnline: "ononline",
OnPageHide: "onpagehide",
OnPageShow: "onpageshow",
OnPaste: "onpaste",
OnPause: "onpause",
OnPlay: "onplay",
OnPlaying: "onplaying",
OnProgress: "onprogress",
OnRateChange: "onratechange",
OnResize: "onresize",
OnReset: "onreset",
OnScroll: "onscroll",
OnSearch: "onsearch",
OnSeeked: "onseeked",
OnSeeking: "onseeking",
OnSelect: "onselect",
OnStalled: "onstalled",
OnSubmit: "onsubmit",
OnSuspend: "onsuspend",
OnTimeUpdate: "ontimeupdate",
OnToggle: "ontoggle",
OnTouchCancel: "ontouchcancel",
OnTouchend: "ontouchend",
OnTouchMove: "ontouchmove",
OnTouchStart: "ontouchstart",
OnUnload: "onunload",
OnVolumeChange: "onvolumechange",
OnWaiting: "onwaiting",
OnWheel: "onwheel",
}
var HtmlEventListener = htmlEventListener{
Paste: "paste",
Pause: "pause",
Play: "play",
Playing: "playing",
Progress: "progress",
RateChange: "ratechange",
Resize: "resize",
Reset: "reset",
Scroll: "scroll",
Search: "search",
Seeked: "seeked",
Seeking: "seeking",
Select: "select",
Stalled: "stalled",
Submit: "submit",
Suspend: "suspend",
TimeUpdate: "timeupdate",
Toggle: "toggle",
TouchCancel: "touchcancel",
Touchend: "touchend",
TouchMove: "touchmove",
TouchStart: "touchstart",
Unload: "unload",
VolumeChange: "volumechange",
Waiting: "waiting",
Wheel: "wheel",
AnimationEnd: "animationend",
AnimationIteration: "animationiteration",
AnimationStart: "animationstart",
ContextMenu: "contextmenu",
FullScreenChange: "fullscreenchange",
FullScreenError: "fullscreenerror",
PopState: "popstate",
TransitionEnd: "transitionend",
Storage: "storage",
ScrollBottom: "scrollbottom",
ElementReached: "elementreached",
}
var InputPlace = inputPlace{
Document: ",",
Window: "`",
Root: "~",
HTML: ".",
Head: "^",
ScreenOrientation: "%",
All: "*",
Parent: "/",
Current: "$",
Target: "!",
Upper: "-",
}
var WasmLanguage = wasmLanguage{
C: "c",
CPP: "c",
Rust: "rust",
CSharp: "csharp",
CSharpMediator: "csharp-m",
GO: "go",
JAVA: "java",
AssemblyScript: "as",
}
Functions ¶
func AppendFetchReplace ¶
Types ¶
type OutputPlace ¶
type OutputPlace struct {
// contains filtered or unexported fields
}
func (OutputPlace) AllAttributes ¶
func (OutputPlace) AllAttributesValue ¶
func (OutputPlace) AllClasses ¶
func (OutputPlace) AttributeIndex ¶
func (OutputPlace) AttributeValue ¶
Operator: '^', '$', '*', '~'
func (OutputPlace) AttributeValueIndex ¶
func (OutputPlace) ChildIndex ¶
func (OutputPlace) ClassIndex ¶
type WebForms ¶
type WebForms struct {
// contains filtered or unexported fields
}
func (*WebForms) AddAttribute ¶
func (*WebForms) AddCacheValue ¶
func (*WebForms) AddCheckBoxTag ¶
func (*WebForms) AddId ¶
Add Creates the Data if it does not exist; otherwise, Appends the New Value to the Existing Value.
func (*WebForms) AddOptionTag ¶
func (*WebForms) AddSaveValue ¶
func (*WebForms) AddTagAfter ¶
func (*WebForms) AddTagBefore ¶
func (*WebForms) AddTagToUp ¶
func (*WebForms) AddTextLineInt ¶
func (*WebForms) AddTextToUp ¶
func (*WebForms) AddVariable ¶
func (*WebForms) AddWebSocket ¶
func (*WebForms) AppendCacheValue ¶
func (*WebForms) AppendForm ¶
func (*WebForms) AppendSaveValue ¶
func (*WebForms) AssertEqual ¶
Unit Testing InputPlace Is Actual, Expected Is Tag/OutputPlace
func (*WebForms) AssertEqualByOutputPlace ¶
func (*WebForms) AssignConfirmEvent ¶
func (*WebForms) AssignDelay ¶
Pre Runner
func (*WebForms) AssignDelayChange ¶
func (*WebForms) AssignInterval ¶
func (*WebForms) AssignIntervalChange ¶
func (*WebForms) AssignRepeat ¶
func (*WebForms) AssignRepeatChange ¶
func (*WebForms) AssignReplace ¶
func (*WebForms) BindINIToTemplate ¶
func (*WebForms) BindJSONToTemplate ¶
func (w *WebForms) BindJSONToTemplate(inputPlace string, jsonText string, path string, pattern string, alsoStartTag bool)
Template Engine Pattern Example: {{value}}, ((value)), *value*, $value;
func (*WebForms) BindXMLToTemplate ¶
func (w *WebForms) BindXMLToTemplate(inputPlace string, xmlText string, path string, pattern string, alsoStartTag bool)
Because XML Elements Are Lowercased, Placeholders Must Use Lowercase Names.
func (*WebForms) CacheAttribute ¶
func (*WebForms) CacheClass ¶
func (*WebForms) CacheHeight ¶
func (*WebForms) CacheIndex ¶
func (*WebForms) CacheLabel ¶
func (*WebForms) CacheNodeLength ¶
func (*WebForms) CacheOuterText ¶
func (*WebForms) CacheReadOnly ¶
func (*WebForms) CacheSelectedIndex ¶
func (*WebForms) CacheStyle ¶
func (*WebForms) CacheTextAlign ¶
func (*WebForms) CacheTextLength ¶
func (*WebForms) CacheTitle ¶
func (*WebForms) CacheValue ¶
func (*WebForms) CacheValueLength ¶
func (*WebForms) CacheVisible ¶
func (*WebForms) CacheWidth ¶
func (*WebForms) CallCommentBack ¶
func (*WebForms) CallDeleteBack ¶
func (*WebForms) CallGetBack ¶
func (*WebForms) CallHeadBack ¶
func (*WebForms) CallMethod ¶
func (*WebForms) CallModuleMethod ¶
func (*WebForms) CallOptionsBack ¶
func (*WebForms) CallPatchBack ¶
func (*WebForms) CallPostBack ¶
func (*WebForms) CallPutBack ¶
func (*WebForms) CallSSEBack ¶
func (*WebForms) CallScript ¶
func (*WebForms) CallSendBack ¶
func (*WebForms) CallWasmBack ¶
func (*WebForms) CallWebSocketBack ¶
func (*WebForms) ChecksumCalculation ¶
func (*WebForms) ClipboardWriteText ¶
func (*WebForms) ConfirmIsFalseAccept ¶
func (*WebForms) ConfirmIsTrueAccept ¶
func (w *WebForms) ConfirmIsTrueAccept(text string, typ string, title string, okText string, cancelText string, interval int) *WebForms
Condition And Loop Condition And Loop Supports Brackets and Then Type: warning, problem, help, success, none Interval: Value 0 is Await (if is not True, all Next Action Controls Waiting for it), Value -1 is Sync Check Once (is Support Bracket or Next Action Control), Value > 0 is Async and is Wait Based on Time Repetition Until it Becomes True (Is Support Bracket or Next Action Control, but is not Support Else). Nested Conditions and Nested Loops are Possible.
func (*WebForms) ConsoleMessage ¶
Type: log, info, warn, error, debug, trace, group, groupend, table
func (*WebForms) ConsoleMessageAssert ¶
func (*WebForms) CreateCustomDOMEvent ¶
func (w *WebForms) CreateCustomDOMEvent(inputPlace string, eventName string, watch string, key string, compare string, value string, rangeValue string, immediate bool, delay any)
Custom Event This Method Is Compatible With EventListener And May Not Be Compatible With Events Written As Attributes In Some Browsers. Watch: attribute, style, text, children, value Compare: greater, less, equal, notequal, includes, startswith, endswith, matches, changed, inrange, lengthgreater, lengthless, lengthequal Range: Only Use For Compare With inrange Value. Split By Comma "," Key: Only Use For Watch With attribute And style Value
func (*WebForms) CreateFormatStorage ¶
Format Storage
func (*WebForms) DecreaseFontSize ¶
func (*WebForms) DecreaseHeight ¶
func (*WebForms) DecreaseMaxLength ¶
func (*WebForms) DecreaseMinLength ¶
Decrease
func (*WebForms) DecreaseValue ¶
func (*WebForms) DecreaseVariable ¶
func (*WebForms) DecreaseWidth ¶
func (*WebForms) DeleteAllCheckBoxTag ¶
func (*WebForms) DeleteAllOptionTag ¶
func (*WebForms) DeleteAllState ¶
func (w *WebForms) DeleteAllState()
func (*WebForms) DeleteAttribute ¶
func (*WebForms) DeleteCheckBoxTag ¶
func (*WebForms) DeleteClass ¶
func (*WebForms) DeleteFormatStorage ¶
func (*WebForms) DeleteInterval ¶
func (*WebForms) DeleteJSON ¶
func (*WebForms) DeleteLabel ¶
func (*WebForms) DeleteModuleMethod ¶
func (*WebForms) DeleteName ¶
func (*WebForms) DeleteOptionTag ¶
func (*WebForms) DeleteParent ¶
func (*WebForms) DeleteState ¶
func (*WebForms) DeleteStyle ¶
func (*WebForms) DeleteText ¶
func (*WebForms) DeleteTextLine ¶
func (*WebForms) DeleteTextLineInt ¶
func (*WebForms) DeleteTitle ¶
func (*WebForms) DeleteValue ¶
func (*WebForms) DeleteVariable ¶
func (*WebForms) DeleteWebSocket ¶
Disconnected WebSocket
func (*WebForms) DisconnectAllSSE ¶
func (w *WebForms) DisconnectAllSSE()
func (*WebForms) ElementExists ¶
func (*WebForms) ElementNotExists ¶
func (*WebForms) EnableReachedElementEvent ¶
func (*WebForms) EnableScrollBottomEvent ¶
func (*WebForms) EnableWebSocket ¶
Enable Calling The EnableWebSocket Or EnableWebSocketOnce Or AddWebSocket Methods Will Cause Any Subsequent Requests (Under WebForms Core Technology) To Operate Under The WebSocket Protocol.
func (*WebForms) EnableWebSocketOnce ¶
func (w *WebForms) EnableWebSocketOnce()
func (*WebForms) EndBracket ¶
func (w *WebForms) EndBracket()
func (*WebForms) EndTransientDOM ¶
func (w *WebForms) EndTransientDOM()
func (*WebForms) ExportToHtmlComment ¶
Export
func (*WebForms) ExportToLineBreak ¶
Using it for SSE Response
func (*WebForms) ForEach ¶
In: Everything Becomes A JSON List. Key: Creates A Temporary Data In The Browser IndexedDB. Key + "i" Creates A Temporary Data To Maintain The Loop Counter In The Browser IndexedDB.
func (*WebForms) GetChecksum ¶
func (*WebForms) GetFormsActionDataLineBreak ¶
func (*WebForms) GetwebFormsData ¶
func (*WebForms) IncreaseFontSize ¶
func (*WebForms) IncreaseHeight ¶
func (*WebForms) IncreaseMaxLength ¶
func (*WebForms) IncreaseMinLength ¶
Increase
func (*WebForms) IncreaseValue ¶
func (*WebForms) IncreaseVariable ¶
func (*WebForms) IncreaseVariableInt ¶
func (*WebForms) IncreaseWidth ¶
func (*WebForms) InsertAttribute ¶
func (*WebForms) InsertCacheValue ¶
func (*WebForms) InsertCheckBoxTag ¶
func (*WebForms) InsertClass ¶
func (*WebForms) InsertId ¶
Insert Creates the Data only if it does not exist; otherwise, does nothing.
func (*WebForms) InsertLabel ¶
func (*WebForms) InsertName ¶
func (*WebForms) InsertOptionTag ¶
func (*WebForms) InsertSaveValue ¶
func (*WebForms) InsertStyle ¶
func (*WebForms) InsertText ¶
func (*WebForms) InsertTitle ¶
func (*WebForms) InsertValue ¶
func (*WebForms) IsGreaterThan ¶
func (*WebForms) IsLessThan ¶
func (*WebForms) IsMatchMedia ¶
func (*WebForms) IsNotEqualTo ¶
func (*WebForms) IsNotMatchMedia ¶
func (*WebForms) IsRegexMatch ¶
func (*WebForms) IsRegexNotMatch ¶
func (*WebForms) LoadModule ¶
Module
func (*WebForms) NotInclude ¶
func (*WebForms) ReloadPage ¶
func (w *WebForms) ReloadPage()
func (*WebForms) RemoveAllCache ¶
func (w *WebForms) RemoveAllCache()
func (*WebForms) RemoveAllSave ¶
func (w *WebForms) RemoveAllSave()
func (*WebForms) RemoveCache ¶
func (*WebForms) RemoveCommentEvent ¶
func (*WebForms) RemoveCommentEventListener ¶
func (*WebForms) RemoveConfirmEvent ¶
func (*WebForms) RemoveDeleteEvent ¶
func (*WebForms) RemoveDeleteEventListener ¶
func (*WebForms) RemoveFrontEvent ¶
func (*WebForms) RemoveFrontEventListener ¶
func (*WebForms) RemoveGetEvent ¶
func (*WebForms) RemoveGetEventListener ¶
func (*WebForms) RemoveHeadEvent ¶
func (*WebForms) RemoveHeadEventListener ¶
func (*WebForms) RemoveMasterPagesEvent ¶
func (*WebForms) RemoveMasterPagesEventListener ¶
func (*WebForms) RemoveMethodEvent ¶
func (*WebForms) RemoveMethodEventListener ¶
func (*WebForms) RemoveModuleMethodEvent ¶
func (*WebForms) RemoveModuleMethodEventListener ¶
func (*WebForms) RemoveOptionsEvent ¶
func (*WebForms) RemoveOptionsEventListener ¶
func (*WebForms) RemovePatchEvent ¶
func (*WebForms) RemovePatchEventListener ¶
func (*WebForms) RemovePostEvent ¶
func (*WebForms) RemovePostEventListener ¶
func (*WebForms) RemovePreventDefaultEvent ¶
func (*WebForms) RemovePreventDefaultEventListener ¶
func (*WebForms) RemovePutEvent ¶
func (*WebForms) RemovePutEventListener ¶
func (*WebForms) RemoveSSEEvent ¶
func (*WebForms) RemoveSSEEventListener ¶
func (*WebForms) RemoveSave ¶
func (*WebForms) RemoveSendEvent ¶
func (*WebForms) RemoveSendEventListener ¶
func (*WebForms) RemoveStopPropagationEvent ¶
func (*WebForms) RemoveStopPropagationEventListener ¶
func (*WebForms) RemoveWasmEvent ¶
func (*WebForms) RemoveWasmEventListener ¶
func (*WebForms) RemoveWebSocketEvent ¶
func (*WebForms) RemoveWebSocketEventListener ¶
func (*WebForms) RepeatConfigure ¶
func (*WebForms) RepeatConfigureWithIndex ¶
func (*WebForms) RepeatWithIndex ¶
func (*WebForms) Replace ¶
If You Don't Use Deep Mode, any Tags Inside the Current Tag Will Simply Be Treated as Strings. Deep Mode Does not Remove Inner Elements.
func (*WebForms) ReplaceActionControl ¶
Action Control
func (*WebForms) ReplaceCacheValue ¶
func (*WebForms) ReplaceSaveValue ¶
func (*WebForms) ReplaceStartTag ¶
HTML Converts Attribute Names to Lowercase, so they Need to Be Written in Lowercase.
func (*WebForms) ResetOption ¶
func (w *WebForms) ResetOption()
func (*WebForms) ResetOptionName ¶
func (*WebForms) RunActionControls ¶
func (*WebForms) SaveAttribute ¶
func (*WebForms) SaveHeight ¶
func (*WebForms) SaveNodeLength ¶
func (*WebForms) SaveOuterText ¶
func (*WebForms) SaveReadOnly ¶
func (*WebForms) SaveSelectedIndex ¶
func (*WebForms) SaveTextAlign ¶
func (*WebForms) SaveTextLength ¶
func (*WebForms) SaveValueLength ¶
func (*WebForms) SaveVisible ¶
func (*WebForms) ServiceWorkerDeleteDynamicCache ¶
func (*WebForms) ServiceWorkerDeleteRoute ¶
Delete All Route And Alias
func (*WebForms) ServiceWorkerDeleteRouteAlias ¶
func (*WebForms) ServiceWorkerDynamicCache ¶
func (*WebForms) ServiceWorkerDynamicCacheTTLUpdate ¶
func (*WebForms) ServiceWorkerPreCacheStatic ¶
func (*WebForms) ServiceWorkerRegister ¶
Service Worker To Use Service Worker, You Need To Add The Elanat Dedicated Module (service-worker.js) On The Client Side
func (*WebForms) ServiceWorkerRouteAlias ¶
func (*WebForms) ServiceWorkerRouteSet ¶
func (*WebForms) SetAttribute ¶
func (*WebForms) SetBackgroundColor ¶
func (*WebForms) SetCache ¶
Calling the SetCache Method Causes Action Control Requests Triggered by events using the GET, POST, PUT, PATCH, DELETE, and OPTIONS Methods, as well as Requests Triggered by the Send event, to be Cached, so the Request will not be Sent to the Server Again.
func (*WebForms) SetCheckBoxTag ¶
func (*WebForms) SetChecked ¶
func (*WebForms) SetCheckedIndex ¶
func (*WebForms) SetCheckedValue ¶
func (*WebForms) SetChecksum ¶
func (w *WebForms) SetChecksum()
func (*WebForms) SetCommentEvent ¶
func (*WebForms) SetCommentEventListener ¶
func (*WebForms) SetDeleteEvent ¶
func (*WebForms) SetDeleteEventListener ¶
func (*WebForms) SetDisabled ¶
func (*WebForms) SetFontBold ¶
func (*WebForms) SetFontName ¶
func (*WebForms) SetFontSize ¶
func (*WebForms) SetFrontEvent ¶
func (*WebForms) SetFrontEventListener ¶
func (*WebForms) SetGetEvent ¶
func (*WebForms) SetGetEventListener ¶
func (*WebForms) SetHeadEvent ¶
func (*WebForms) SetHeadEventListener ¶
func (*WebForms) SetHeadTitle ¶
func (*WebForms) SetId ¶
Set Creates the Data if it does not exist; otherwise, Replaces the Existing Value with the New Value.
func (*WebForms) SetMasterPagesEvent ¶
func (*WebForms) SetMasterPagesEventListener ¶
func (*WebForms) SetMaxLength ¶
func (*WebForms) SetMethodEvent ¶
func (*WebForms) SetMethodEventListener ¶
func (*WebForms) SetMinLength ¶
func (*WebForms) SetModuleMethodEvent ¶
func (*WebForms) SetModuleMethodEventListener ¶
func (*WebForms) SetMorphByOutputPlace ¶
func (*WebForms) SetOptionTag ¶
func (*WebForms) SetOptionsEvent ¶
func (*WebForms) SetOptionsEventListener ¶
func (*WebForms) SetPatchEvent ¶
func (*WebForms) SetPatchEventListener ¶
func (*WebForms) SetPostEvent ¶
func (*WebForms) SetPostEventAddView ¶
func (*WebForms) SetPostEventListener ¶
func (*WebForms) SetPostEventListenerAddView ¶
func (*WebForms) SetPreventDefaultEvent ¶
func (*WebForms) SetPreventDefaultEventListener ¶
func (*WebForms) SetPutEvent ¶
func (*WebForms) SetPutEventListener ¶
func (*WebForms) SetReadOnly ¶
func (*WebForms) SetReflection ¶
func (*WebForms) SetReflectionByOutputPlace ¶
func (*WebForms) SetSSEEvent ¶
func (*WebForms) SetSSEEventListener ¶
func (*WebForms) SetSave ¶
func (w *WebForms) SetSave()
Calling the SetSave Method Causes Action Control Requests Triggered by Events Using the GET, POST, PUT, PATCH, DELETE, and OPTIONS Methods, as well as Requests Triggered by the Send Event, to be Temporarily Saved on the Active Page, so the Request will not be Sent to the Server Again.
func (*WebForms) SetSelectedIndex ¶
func (*WebForms) SetSelectedValue ¶
func (*WebForms) SetSendEvent ¶
IsMultiPart: If this value is true, the data will be sent based on the Form and with the "content" key.
func (*WebForms) SetSendEventListener ¶
func (*WebForms) SetStopPropagationEvent ¶
func (*WebForms) SetStopPropagationEventListener ¶
func (*WebForms) SetTextAlign ¶
func (*WebForms) SetTextColor ¶
func (*WebForms) SetVisible ¶
func (*WebForms) SetWasmEvent ¶
func (*WebForms) SetWasmEventListener ¶
func (*WebForms) SetWebSocketEvent ¶
func (*WebForms) SetWebSocketEventListener ¶
func (*WebForms) StartBracket ¶
func (w *WebForms) StartBracket()
func (*WebForms) StartState ¶
func (w *WebForms) StartState()
This Index Is Automatically Run After Changing The Browser History (Back And Forward Buttons)
func (*WebForms) ThenConfigure ¶
func (*WebForms) TriggerEvent ¶
func (w *WebForms) TriggerEvent(inputPlace string, htmlEventListener string, constructorName ...string)
Event ConstructorName: mouseevent, keyboardevent, uievent, focusevent, inputevent, event All Method in "Event" Section Only Support Dynamic Args Once. To Support Invoking Dynamic Arguments on a Momentary Basis, Use "EventListener" Section Methods.
func (*WebForms) UnloadModule ¶
func (*WebForms) UpdateTexLine ¶
func (*WebForms) UpdateTexLineInt ¶
func (*WebForms) UpdateVariable ¶
func (*WebForms) UseOnlyChangeUpdate ¶
func (*WebForms) UseWebSocket ¶
Use InputPlace Using Only For form Element